@@ -1,4 +1,4 @@
-use command_prelude::*;
+use crate::command_prelude::*;
 
 use cargo::ops::{self, CompileFilter};
 
@@ -89,15 +89,18 @@ To get the list of all options available for the test binaries use this:
         )
 }
 
-pub fn exec(config: &mut Config, args: &ArgMatches) -> CliResult {
+pub fn exec(config: &mut Config, args: &ArgMatches<'_>) -> CliResult {
     let ws = args.workspace(config)?;
 
-    let mut compile_opts = args.compile_options(config, CompileMode::Test)?;
+    let mut compile_opts = args.compile_options(config, CompileMode::Test, Some(&ws))?;
 
     let doc = args.is_present("doc");
     if doc {
         if let CompileFilter::Only { .. } = compile_opts.filter {
-            return Err(CliError::new(format_err!("Can't mix --doc with other target selecting options"), 101))
+            return Err(CliError::new(
+                failure::format_err!("Can't mix --doc with other target selecting options"),
+                101,
+            ));
         }
         compile_opts.build_config.mode = CompileMode::Doctest;
         compile_opts.filter = ops::CompileFilter::new(
@@ -134,7 +137,7 @@ pub fn exec(config: &mut Config, args: &ArgMatches) -> CliResult {
     match err {
         None => Ok(()),
         Some(err) => Err(match err.exit.as_ref().and_then(|e| e.code()) {
-            Some(i) => CliError::new(format_err!("{}", err.hint(&ws)), i),
+            Some(i) => CliError::new(failure::format_err!("{}", err.hint(&ws)), i),
             None => CliError::new(err.into(), 101),
         }),
     }
