@@ -8,24 +8,23 @@ use std::path::{Path, PathBuf};
 use std::time::{Duration, Instant};
 
 use bytesize::ByteSize;
-use curl;
 use curl::easy::{Easy, HttpVersion};
 use curl::multi::{EasyHandle, Multi};
-use curl_sys;
 use failure::ResultExt;
 use lazycell::LazyCell;
+use log::{debug, warn};
 use semver::Version;
 use serde::ser;
-use toml;
+use serde::Serialize;
 
-use core::interning::InternedString;
-use core::source::MaybePackage;
-use core::{Dependency, Manifest, PackageId, SourceId, Target};
-use core::{FeatureMap, SourceMap, Summary};
-use ops;
-use util::errors::{CargoResult, CargoResultExt, HttpNot200};
-use util::network::Retry;
-use util::{self, internal, lev_distance, Config, Progress, ProgressStyle};
+use crate::core::interning::InternedString;
+use crate::core::source::MaybePackage;
+use crate::core::{Dependency, Manifest, PackageId, SourceId, Target};
+use crate::core::{FeatureMap, SourceMap, Summary};
+use crate::ops;
+use crate::util::errors::{CargoResult, CargoResultExt, HttpNot200};
+use crate::util::network::Retry;
+use crate::util::{self, internal, lev_distance, Config, Progress, ProgressStyle};
 
 /// Information about a package that is available somewhere in the file system.
 ///
@@ -55,7 +54,7 @@ impl PartialOrd for Package {
 #[derive(Serialize)]
 struct SerializedPackage<'a> {
     name: &'a str,
-    version: &'a str,
+    version: &'a Version,
     id: PackageId,
     license: Option<&'a str>,
     license_file: Option<&'a str>,
@@ -64,7 +63,7 @@ struct SerializedPackage<'a> {
     dependencies: &'a [Dependency],
     targets: Vec<&'a Target>,
     features: &'a FeatureMap,
-    manifest_path: &'a str,
+    manifest_path: &'a Path,
     metadata: Option<&'a toml::Value>,
     authors: &'a [String],
     categories: &'a [String],
@@ -72,6 +71,7 @@ struct SerializedPackage<'a> {
     readme: Option<&'a str>,
     repository: Option<&'a str>,
     edition: &'a str,
+    links: Option<&'a str>,
     #[serde(skip_serializing_if = "Option::is_none")]
     metabuild: Option<&'a Vec<String>>,
 }
@@ -104,7 +104,7 @@ impl ser::Serialize for Package {
 
         SerializedPackage {
             name: &*package_id.name(),
-            version: &package_id.version().to_string(),
+            version: &package_id.version(),
             id: package_id,
             license,
             license_file,
@@ -113,7 +113,7 @@ impl ser::Serialize for Package {
             dependencies: summary.dependencies(),
             targets,
             features: summary.features(),
-            manifest_path: &self.manifest_path.display().to_string(),
+            manifest_path: &self.manifest_path,
             metadata: self.manifest.custom_metadata(),
             authors,
             categories,
@@ -121,6 +121,7 @@ impl ser::Serialize for Package {
             readme,
             repository,
             edition: &self.manifest.edition().to_string(),
+            links: self.manifest.links(),
             metabuild: self.manifest.metabuild(),
         }
         .serialize(s)
@@ -233,13 +234,13 @@ impl Package {
 }
 
 impl fmt::Display for Package {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "{}", self.summary().package_id())
     }
 }
 
 impl fmt::Debug for Package {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         f.debug_struct("Package")
             .field("id", &self.summary().package_id())
             .field("..", &"..")
@@ -411,7 +412,7 @@ impl<'cfg> PackageSet<'cfg> {
         Ok(pkgs)
     }
 
-    pub fn sources(&self) -> Ref<SourceMap<'cfg>> {
+    pub fn sources(&self) -> Ref<'_, SourceMap<'cfg>> {
         self.sources.borrow()
     }
 }
@@ -427,7 +428,7 @@ macro_rules! try_old_curl {
             }
         } else {
             result.with_context(|_| {
-                format_err!("failed to enable {}, is curl not built right?", $msg)
+                failure::format_err!("failed to enable {}, is curl not built right?", $msg)
             })?;
         }
     };
@@ -460,7 +461,7 @@ impl<'a, 'cfg> Downloads<'a, 'cfg> {
             .ok_or_else(|| internal(format!("couldn't find source for `{}`", id)))?;
         let pkg = source
             .download(id)
-            .chain_err(|| format_err!("unable to get packages from source"))?;
+            .chain_err(|| failure::format_err!("unable to get packages from source"))?;
         let (url, descriptor) = match pkg {
             MaybePackage::Ready(pkg) => {
                 debug!("{} doesn't need a download", id);
@@ -598,7 +599,7 @@ impl<'a, 'cfg> Downloads<'a, 'cfg> {
                 let timed_out = &dl.timed_out;
                 let url = &dl.url;
                 dl.retry
-                    .try(|| {
+                    .r#try(|| {
                         if let Err(e) = result {
                             // If this error is "aborted by callback" then that's
                             // probably because our progress callback aborted due to
@@ -817,7 +818,7 @@ impl<'a, 'cfg> Downloads<'a, 'cfg> {
         true
     }
 
-    fn tick(&self, why: WhyTick) -> CargoResult<()> {
+    fn tick(&self, why: WhyTick<'_>) -> CargoResult<()> {
         let mut progress = self.progress.borrow_mut();
         let progress = progress.as_mut().unwrap();
 
@@ -908,17 +909,17 @@ mod tls {
 
     thread_local!(static PTR: Cell<usize> = Cell::new(0));
 
-    pub(crate) fn with<R>(f: impl FnOnce(Option<&Downloads>) -> R) -> R {
+    pub(crate) fn with<R>(f: impl FnOnce(Option<&Downloads<'_, '_>>) -> R) -> R {
         let ptr = PTR.with(|p| p.get());
         if ptr == 0 {
             f(None)
         } else {
-            unsafe { f(Some(&*(ptr as *const Downloads))) }
+            unsafe { f(Some(&*(ptr as *const Downloads<'_, '_>))) }
         }
     }
 
-    pub(crate) fn set<R>(dl: &Downloads, f: impl FnOnce() -> R) -> R {
-        struct Reset<'a, T: Copy + 'a>(&'a Cell<T>, T);
+    pub(crate) fn set<R>(dl: &Downloads<'_, '_>, f: impl FnOnce() -> R) -> R {
+        struct Reset<'a, T: Copy>(&'a Cell<T>, T);
 
         impl<'a, T: Copy> Drop for Reset<'a, T> {
             fn drop(&mut self) {
@@ -928,7 +929,7 @@ mod tls {
 
         PTR.with(|p| {
             let _reset = Reset(p, p.get());
-            p.set(dl as *const Downloads as usize);
+            p.set(dl as *const Downloads<'_, '_> as usize);
             f()
         })
     }
