@@ -1,13 +1,15 @@
 use std::collections::HashSet;
 use std::{cmp, fmt, hash};
 
-use core::compiler::CompileMode;
-use core::interning::InternedString;
-use core::{Features, PackageId, PackageIdSpec, PackageSet, Shell};
-use util::errors::CargoResultExt;
-use util::lev_distance::lev_distance;
-use util::toml::{ProfilePackageSpec, StringOrBool, TomlProfile, TomlProfiles, U32OrBool};
-use util::{CargoResult, Config};
+use serde::Deserialize;
+
+use crate::core::compiler::CompileMode;
+use crate::core::interning::InternedString;
+use crate::core::{Features, PackageId, PackageIdSpec, PackageSet, Shell};
+use crate::util::errors::CargoResultExt;
+use crate::util::lev_distance::lev_distance;
+use crate::util::toml::{ProfilePackageSpec, StringOrBool, TomlProfile, TomlProfiles, U32OrBool};
+use crate::util::{CargoResult, Config};
 
 /// Collection of all user profiles.
 #[derive(Clone, Debug)]
@@ -130,7 +132,11 @@ impl Profiles {
     }
 
     /// Used to check for overrides for non-existing packages.
-    pub fn validate_packages(&self, shell: &mut Shell, packages: &PackageSet) -> CargoResult<()> {
+    pub fn validate_packages(
+        &self,
+        shell: &mut Shell,
+        packages: &PackageSet<'_>,
+    ) -> CargoResult<()> {
         self.dev.validate_packages(shell, packages)?;
         self.release.validate_packages(shell, packages)?;
         self.test.validate_packages(shell, packages)?;
@@ -177,7 +183,7 @@ impl ProfileMaker {
         profile
     }
 
-    fn validate_packages(&self, shell: &mut Shell, packages: &PackageSet) -> CargoResult<()> {
+    fn validate_packages(&self, shell: &mut Shell, packages: &PackageSet<'_>) -> CargoResult<()> {
         self.validate_packages_toml(shell, packages, &self.toml, true)?;
         self.validate_packages_toml(shell, packages, &self.config, false)?;
         Ok(())
@@ -186,7 +192,7 @@ impl ProfileMaker {
     fn validate_packages_toml(
         &self,
         shell: &mut Shell,
-        packages: &PackageSet,
+        packages: &PackageSet<'_>,
         toml: &Option<TomlProfile>,
         warn_unmatched: bool,
     ) -> CargoResult<()> {
@@ -225,7 +231,7 @@ impl ProfileMaker {
                         .map(|spec| spec.to_string())
                         .collect::<Vec<_>>()
                         .join(", ");
-                    bail!(
+                    failure::bail!(
                         "multiple profile overrides in profile `{}` match package `{}`\n\
                          found profile override specs: {}",
                         self.default.name,
@@ -434,7 +440,7 @@ compact_debug! {
 }
 
 impl fmt::Display for Profile {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "Profile({})", self.name)
     }
 }
@@ -637,12 +643,14 @@ impl ConfigProfiles {
         if let Some(ref profile) = self.dev {
             profile
                 .validate("dev", features, warnings)
-                .chain_err(|| format_err!("config profile `profile.dev` is not valid"))?;
+                .chain_err(|| failure::format_err!("config profile `profile.dev` is not valid"))?;
         }
         if let Some(ref profile) = self.release {
             profile
                 .validate("release", features, warnings)
-                .chain_err(|| format_err!("config profile `profile.release` is not valid"))?;
+                .chain_err(|| {
+                    failure::format_err!("config profile `profile.release` is not valid")
+                })?;
         }
         Ok(())
     }
