@@ -52,14 +52,14 @@ use std::mem;
 use std::rc::Rc;
 use std::time::{Duration, Instant};
 
-use semver;
+use log::{debug, trace};
 
-use core::interning::InternedString;
-use core::PackageIdSpec;
-use core::{Dependency, PackageId, Registry, Summary};
-use util::config::Config;
-use util::errors::CargoResult;
-use util::profile;
+use crate::core::interning::InternedString;
+use crate::core::PackageIdSpec;
+use crate::core::{Dependency, PackageId, Registry, Summary};
+use crate::util::config::Config;
+use crate::util::errors::CargoResult;
+use crate::util::profile;
 
 use self::context::{Activations, Context};
 use self::types::{Candidate, ConflictReason, DepsFrame, GraphNode};
@@ -108,9 +108,9 @@ mod types;
 /// * `print_warnings` - whether or not to print backwards-compatibility
 ///   warnings and such
 pub fn resolve(
-    summaries: &[(Summary, Method)],
+    summaries: &[(Summary, Method<'_>)],
     replacements: &[(PackageIdSpec, Dependency)],
-    registry: &mut Registry,
+    registry: &mut dyn Registry,
     try_to_use: &HashSet<PackageId>,
     config: Option<&Config>,
     print_warnings: bool,
@@ -167,8 +167,8 @@ pub fn resolve(
 /// dependency graph, cx.resolve is returned.
 fn activate_deps_loop(
     mut cx: Context,
-    registry: &mut RegistryQueryer,
-    summaries: &[(Summary, Method)],
+    registry: &mut RegistryQueryer<'_>,
+    summaries: &[(Summary, Method<'_>)],
     config: Option<&Config>,
 ) -> CargoResult<Context> {
     let mut backtrack_stack = Vec::new();
@@ -580,10 +580,10 @@ fn activate_deps_loop(
 /// iterate through next.
 fn activate(
     cx: &mut Context,
-    registry: &mut RegistryQueryer,
+    registry: &mut RegistryQueryer<'_>,
     parent: Option<(&Summary, &Dependency)>,
     candidate: Candidate,
-    method: &Method,
+    method: &Method<'_>,
 ) -> ActivateResult<Option<(DepsFrame, Duration)>> {
     if let Some((parent, dep)) = parent {
         cx.resolve_graph.push(GraphNode::Link(
@@ -845,7 +845,7 @@ fn check_cycles(resolve: &Resolve, activations: &Activations) -> CargoResult<()>
     ) -> CargoResult<()> {
         // See if we visited ourselves
         if !visited.insert(id) {
-            bail!(
+            failure::bail!(
                 "cyclic package dependency: package `{}` depends on itself. Cycle:\n{}",
                 id,
                 errors::describe_path(&resolve.path_to_top(&id))
@@ -896,7 +896,7 @@ fn check_duplicate_pkgs_in_lockfile(resolve: &Resolve) -> CargoResult<()> {
     for pkg_id in resolve.iter() {
         let encodable_pkd_id = encode::encodable_package_id(pkg_id);
         if let Some(prev_pkg_id) = unique_pkg_ids.insert(encodable_pkd_id, pkg_id) {
-            bail!(
+            failure::bail!(
                 "package collision in the lockfile: packages {} and {} are different, \
                  but only one can be written to lockfile unambiguously",
                 prev_pkg_id,
