@@ -6,9 +6,9 @@ use std::iter::FromIterator;
 
 use url::Url;
 
-use core::{Dependency, PackageId, PackageIdSpec, Summary, Target};
-use util::errors::CargoResult;
-use util::Graph;
+use crate::core::{Dependency, PackageId, PackageIdSpec, Summary, Target};
+use crate::util::errors::CargoResult;
+use crate::util::Graph;
 
 use super::encode::Metadata;
 
@@ -94,7 +94,7 @@ impl Resolve {
                 // desires stronger checksum guarantees than can be afforded
                 // elsewhere.
                 if cksum.is_none() {
-                    bail!(
+                    failure::bail!(
                         "\
 checksum for `{}` was not previously calculated, but a checksum could now \
 be calculated
@@ -116,7 +116,7 @@ this could be indicative of a few possible situations:
                 // more realistically we were overridden with a source that does
                 // not have checksums.
                 } else if mine.is_none() {
-                    bail!(
+                    failure::bail!(
                         "\
 checksum for `{}` could not be calculated, but a checksum is listed in \
 the existing lock file
@@ -137,7 +137,7 @@ unable to verify that `{0}` is the same as when the lockfile was generated
                 // must both be Some, in which case the checksum now differs.
                 // That's quite bad!
                 } else {
-                    bail!(
+                    failure::bail!(
                         "\
 checksum for `{}` changed between lock files
 
@@ -243,14 +243,14 @@ unable to verify that `{0}` is the same as when the lockfile was generated
             if n == name {
                 continue;
             }
-            bail!(
+            failure::bail!(
                 "multiple dependencies listed for the same crate must \
                  all have the same name, but the dependency on `{}` \
                  is listed as having different names",
                 to
             );
         }
-        Ok(name.to_string())
+        Ok(name)
     }
 
     fn dependencies_listed(&self, from: PackageId, to: PackageId) -> &[Dependency] {
@@ -276,7 +276,7 @@ unable to verify that `{0}` is the same as when the lockfile was generated
 }
 
 impl fmt::Debug for Resolve {
-    fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         writeln!(fmt, "graph: {:?}", self.graph)?;
         writeln!(fmt, "\nfeatures: {{")?;
         for (pkg, features) in &self.features {
