@@ -1,8 +1,8 @@
 use std::collections::hash_map::HashMap;
 use std::fmt;
 
-use core::{Dependency, Package, PackageId, Summary};
-use util::CargoResult;
+use crate::core::{Dependency, Package, PackageId, Summary};
+use crate::util::CargoResult;
 
 mod source_id;
 
@@ -28,13 +28,13 @@ pub trait Source {
     fn requires_precise(&self) -> bool;
 
     /// Attempt to find the packages that match a dependency request.
-    fn query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()>;
+    fn query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()>;
 
     /// Attempt to find the packages that are close to a dependency request.
     /// Each source gets to define what `close` means for it.
     /// path/git sources may return all dependencies that are at that uri.
     /// where as an Index source may return dependencies that have the same canonicalization.
-    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()>;
+    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()>;
 
     fn query_vec(&mut self, dep: &Dependency) -> CargoResult<Vec<Summary>> {
         let mut ret = Vec::new();
@@ -83,6 +83,11 @@ pub trait Source {
     fn is_replaced(&self) -> bool {
         false
     }
+
+    /// Add a number of crates that should be whitelisted for showing up during
+    /// queries, even if they are yanked. Currently only applies to registry
+    /// sources.
+    fn add_to_yanked_whitelist(&mut self, pkgs: &[PackageId]);
 }
 
 pub enum MaybePackage {
@@ -112,12 +117,12 @@ impl<'a, T: Source + ?Sized + 'a> Source for Box<T> {
     }
 
     /// Forwards to `Source::query`
-    fn query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()> {
+    fn query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         (**self).query(dep, f)
     }
 
     /// Forwards to `Source::query`
-    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()> {
+    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         (**self).fuzzy_query(dep, f)
     }
 
@@ -152,6 +157,10 @@ impl<'a, T: Source + ?Sized + 'a> Source for Box<T> {
     fn is_replaced(&self) -> bool {
         (**self).is_replaced()
     }
+
+    fn add_to_yanked_whitelist(&mut self, pkgs: &[PackageId]) {
+        (**self).add_to_yanked_whitelist(pkgs);
+    }
 }
 
 impl<'a, T: Source + ?Sized + 'a> Source for &'a mut T {
@@ -171,11 +180,11 @@ impl<'a, T: Source + ?Sized + 'a> Source for &'a mut T {
         (**self).requires_precise()
     }
 
-    fn query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()> {
+    fn query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         (**self).query(dep, f)
     }
 
-    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()> {
+    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         (**self).fuzzy_query(dep, f)
     }
 
@@ -206,17 +215,21 @@ impl<'a, T: Source + ?Sized + 'a> Source for &'a mut T {
     fn is_replaced(&self) -> bool {
         (**self).is_replaced()
     }
+
+    fn add_to_yanked_whitelist(&mut self, pkgs: &[PackageId]) {
+        (**self).add_to_yanked_whitelist(pkgs);
+    }
 }
 
 /// A `HashMap` of `SourceId` -> `Box<Source>`
 #[derive(Default)]
 pub struct SourceMap<'src> {
-    map: HashMap<SourceId, Box<Source + 'src>>,
+    map: HashMap<SourceId, Box<dyn Source + 'src>>,
 }
 
 // impl debug on source requires specialization, if even desirable at all
 impl<'src> fmt::Debug for SourceMap<'src> {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "SourceMap ")?;
         f.debug_set().entries(self.map.keys()).finish()
     }
@@ -236,31 +249,31 @@ impl<'src> SourceMap<'src> {
     }
 
     /// Like `HashMap::get`
-    pub fn get(&self, id: SourceId) -> Option<&(Source + 'src)> {
+    pub fn get(&self, id: SourceId) -> Option<&(dyn Source + 'src)> {
         let source = self.map.get(&id);
 
         source.map(|s| {
-            let s: &(Source + 'src) = &**s;
+            let s: &(dyn Source + 'src) = &**s;
             s
         })
     }
 
     /// Like `HashMap::get_mut`
-    pub fn get_mut(&mut self, id: SourceId) -> Option<&mut (Source + 'src)> {
+    pub fn get_mut(&mut self, id: SourceId) -> Option<&mut (dyn Source + 'src)> {
         self.map.get_mut(&id).map(|s| {
-            let s: &mut (Source + 'src) = &mut **s;
+            let s: &mut (dyn Source + 'src) = &mut **s;
             s
         })
     }
 
     /// Like `HashMap::get`, but first calculates the `SourceId` from a
     /// `PackageId`
-    pub fn get_by_package_id(&self, pkg_id: PackageId) -> Option<&(Source + 'src)> {
+    pub fn get_by_package_id(&self, pkg_id: PackageId) -> Option<&(dyn Source + 'src)> {
         self.get(pkg_id.source_id())
     }
 
     /// Like `HashMap::insert`, but derives the SourceId key from the Source
-    pub fn insert(&mut self, source: Box<Source + 'src>) {
+    pub fn insert(&mut self, source: Box<dyn Source + 'src>) {
         let id = source.source_id();
         self.map.insert(id, source);
     }
@@ -276,14 +289,14 @@ impl<'src> SourceMap<'src> {
     }
 
     /// Like `HashMap::values`
-    pub fn sources<'a>(&'a self) -> impl Iterator<Item = &'a Box<Source + 'src>> {
+    pub fn sources<'a>(&'a self) -> impl Iterator<Item = &'a Box<dyn Source + 'src>> {
         self.map.values()
     }
 
     /// Like `HashMap::iter_mut`
     pub fn sources_mut<'a>(
         &'a mut self,
-    ) -> impl Iterator<Item = (&'a SourceId, &'a mut (Source + 'src))> {
+    ) -> impl Iterator<Item = (&'a SourceId, &'a mut (dyn Source + 'src))> {
         self.map.iter_mut().map(|(a, b)| (a, &mut **b))
     }
 }
