@@ -26,15 +26,17 @@ use std::collections::{HashMap, HashSet};
 use std::path::PathBuf;
 use std::sync::Arc;
 
-use core::compiler::{BuildConfig, BuildContext, Compilation, Context, DefaultExecutor, Executor};
-use core::compiler::{CompileMode, Kind, Unit};
-use core::profiles::{Profiles, UnitFor};
-use core::resolver::{Method, Resolve};
-use core::{Package, Source, Target};
-use core::{PackageId, PackageIdSpec, TargetKind, Workspace};
-use ops;
-use util::config::Config;
-use util::{lev_distance, profile, CargoResult};
+use crate::core::compiler::{
+    BuildConfig, BuildContext, Compilation, Context, DefaultExecutor, Executor,
+};
+use crate::core::compiler::{CompileMode, Kind, Unit};
+use crate::core::profiles::{Profiles, UnitFor};
+use crate::core::resolver::{Method, Resolve};
+use crate::core::{Package, Source, Target};
+use crate::core::{PackageId, PackageIdSpec, TargetKind, Workspace};
+use crate::ops;
+use crate::util::config::Config;
+use crate::util::{lev_distance, profile, CargoResult};
 
 /// Contains information about how a package should be compiled.
 #[derive(Debug)]
@@ -101,13 +103,13 @@ impl Packages {
         Ok(match (all, exclude.len(), package.len()) {
             (false, 0, 0) => Packages::Default,
             (false, 0, _) => Packages::Packages(package),
-            (false, _, _) => bail!("--exclude can only be used together with --all"),
+            (false, _, _) => failure::bail!("--exclude can only be used together with --all"),
             (true, 0, _) => Packages::All,
             (true, _, _) => Packages::OptOut(exclude),
         })
     }
 
-    pub fn to_package_id_specs(&self, ws: &Workspace) -> CargoResult<Vec<PackageIdSpec>> {
+    pub fn to_package_id_specs(&self, ws: &Workspace<'_>) -> CargoResult<Vec<PackageIdSpec>> {
         let specs = match *self {
             Packages::All => ws
                 .members()
@@ -135,18 +137,18 @@ impl Packages {
         };
         if specs.is_empty() {
             if ws.is_virtual() {
-                bail!(
+                failure::bail!(
                     "manifest path `{}` contains no package: The manifest is virtual, \
                      and the workspace has no members.",
                     ws.root().display()
                 )
             }
-            bail!("no packages to compile")
+            failure::bail!("no packages to compile")
         }
         Ok(specs)
     }
 
-    pub fn get_packages<'ws>(&self, ws: &'ws Workspace) -> CargoResult<Vec<&'ws Package>> {
+    pub fn get_packages<'ws>(&self, ws: &'ws Workspace<'_>) -> CargoResult<Vec<&'ws Package>> {
         let packages: Vec<_> = match self {
             Packages::Default => ws.default_members().collect(),
             Packages::All => ws.members().collect(),
@@ -160,7 +162,10 @@ impl Packages {
                     ws.members()
                         .find(|pkg| pkg.name().as_str() == name)
                         .ok_or_else(|| {
-                            format_err!("package `{}` is not a member of the workspace", name)
+                            failure::format_err!(
+                                "package `{}` is not a member of the workspace",
+                                name
+                            )
                         })
                 })
                 .collect::<CargoResult<Vec<_>>>()?,
@@ -195,7 +200,7 @@ pub fn compile<'a>(
     ws: &Workspace<'a>,
     options: &CompileOptions<'a>,
 ) -> CargoResult<Compilation<'a>> {
-    let exec: Arc<Executor> = Arc::new(DefaultExecutor);
+    let exec: Arc<dyn Executor> = Arc::new(DefaultExecutor);
     compile_with_exec(ws, options, &exec)
 }
 
@@ -204,7 +209,7 @@ pub fn compile<'a>(
 pub fn compile_with_exec<'a>(
     ws: &Workspace<'a>,
     options: &CompileOptions<'a>,
-    exec: &Arc<Executor>,
+    exec: &Arc<dyn Executor>,
 ) -> CargoResult<Compilation<'a>> {
     ws.emit_warnings()?;
     compile_ws(ws, None, options, exec)
@@ -212,9 +217,9 @@ pub fn compile_with_exec<'a>(
 
 pub fn compile_ws<'a>(
     ws: &Workspace<'a>,
-    source: Option<Box<Source + 'a>>,
+    source: Option<Box<dyn Source + 'a>>,
     options: &CompileOptions<'a>,
-    exec: &Arc<Executor>,
+    exec: &Arc<dyn Executor>,
 ) -> CargoResult<Compilation<'a>> {
     let CompileOptions {
         config,
@@ -265,7 +270,7 @@ pub fn compile_ws<'a>(
             && !ws.is_member(pkg)
             && pkg.dependencies().iter().any(|dep| !dep.is_transitive())
         {
-            bail!(
+            failure::bail!(
                 "package `{}` cannot be tested because it requires dev-dependencies \
                  and is not a member of the workspace",
                 pkg.name()
@@ -302,7 +307,7 @@ pub fn compile_ws<'a>(
     let mut extra_compiler_args = HashMap::new();
     if let Some(args) = extra_args {
         if units.len() != 1 {
-            bail!(
+            failure::bail!(
                 "extra arguments to `{}` can only be passed to one \
                  target, consider filtering\nthe package by passing \
                  e.g. `--lib` or `--bin NAME` to specify a single target",
@@ -487,7 +492,7 @@ struct Proposal<'a> {
 /// compile. Dependencies for these targets are computed later in
 /// `unit_dependencies`.
 fn generate_targets<'a>(
-    ws: &Workspace,
+    ws: &Workspace<'_>,
     profiles: &Profiles,
     packages: &[&'a Package],
     filter: &CompileFilter,
@@ -574,7 +579,7 @@ fn generate_targets<'a>(
     };
 
     // Create a list of proposed targets.
-    let mut proposals: Vec<Proposal> = Vec::new();
+    let mut proposals: Vec<Proposal<'_>> = Vec::new();
 
     match *filter {
         CompileFilter::Default {
@@ -637,9 +642,12 @@ fn generate_targets<'a>(
                 if !all_targets && libs.is_empty() {
                     let names = packages.iter().map(|pkg| pkg.name()).collect::<Vec<_>>();
                     if names.len() == 1 {
-                        bail!("no library targets found in package `{}`", names[0]);
+                        failure::bail!("no library targets found in package `{}`", names[0]);
                     } else {
-                        bail!("no library targets found in packages: {}", names.join(", "));
+                        failure::bail!(
+                            "no library targets found in packages: {}",
+                            names.join(", ")
+                        );
                     }
                 }
                 proposals.extend(libs);
@@ -728,7 +736,7 @@ fn generate_targets<'a>(
                 .iter()
                 .map(|s| format!("`{}`", s))
                 .collect();
-            bail!(
+            failure::bail!(
                 "target `{}` in package `{}` requires the features: {}\n\
                  Consider enabling them by passing e.g. `--features=\"{}\"`",
                 target.name(),
@@ -863,13 +871,13 @@ fn find_named_targets<'a>(
             .min_by_key(|t| t.0)
             .map(|t| t.1);
         match suggestion {
-            Some(s) => bail!(
+            Some(s) => failure::bail!(
                 "no {} target named `{}`\n\nDid you mean `{}`?",
                 target_desc,
                 target_name,
                 s.name()
             ),
-            None => bail!("no {} target named `{}`", target_desc, target_name),
+            None => failure::bail!("no {} target named `{}`", target_desc, target_name),
         }
     }
     Ok(result)
