@@ -1,12 +1,20 @@
 use std::collections::HashSet;
 
-use core::registry::PackageRegistry;
-use core::resolver::{self, Method, Resolve};
-use core::{PackageId, PackageIdSpec, PackageSet, Source, SourceId, Workspace};
-use ops;
-use sources::PathSource;
-use util::errors::{CargoResult, CargoResultExt};
-use util::profile;
+use log::{debug, trace};
+
+use crate::core::registry::PackageRegistry;
+use crate::core::resolver::{self, Method, Resolve};
+use crate::core::{PackageId, PackageIdSpec, PackageSet, Source, SourceId, Workspace};
+use crate::ops;
+use crate::sources::PathSource;
+use crate::util::errors::{CargoResult, CargoResultExt};
+use crate::util::profile;
+
+const UNUSED_PATCH_WARNING: &str = "\
+Check that the patched package version and available features are compatible
+with the dependency requirements. If the patch has a different version from
+what is locked in the Cargo.lock file, run `cargo update` to use the new
+version. This may also occur with an optional dependency that is not enabled.";
 
 /// Resolve all dependencies for the workspace using the previous
 /// lockfile as a guide if present.
@@ -24,7 +32,7 @@ pub fn resolve_ws<'a>(ws: &Workspace<'a>) -> CargoResult<(PackageSet<'a>, Resolv
 /// taking into account `paths` overrides and activated features.
 pub fn resolve_ws_precisely<'a>(
     ws: &Workspace<'a>,
-    source: Option<Box<Source + 'a>>,
+    source: Option<Box<dyn Source + 'a>>,
     features: &[String],
     all_features: bool,
     no_default_features: bool,
@@ -46,8 +54,8 @@ pub fn resolve_ws_precisely<'a>(
 
 pub fn resolve_ws_with_method<'a>(
     ws: &Workspace<'a>,
-    source: Option<Box<Source + 'a>>,
-    method: Method,
+    source: Option<Box<dyn Source + 'a>>,
+    method: Method<'_>,
     specs: &[PackageIdSpec],
 ) -> CargoResult<(PackageSet<'a>, Resolve)> {
     let mut registry = PackageRegistry::new(ws.config())?;
@@ -136,7 +144,7 @@ fn resolve_with_registry<'cfg>(
 pub fn resolve_with_previous<'cfg>(
     registry: &mut PackageRegistry<'cfg>,
     ws: &Workspace<'cfg>,
-    method: Method,
+    method: Method<'_>,
     previous: Option<&Resolve>,
     to_avoid: Option<&HashSet<PackageId>>,
     specs: &[PackageIdSpec],
@@ -230,7 +238,7 @@ pub fn resolve_with_previous<'cfg>(
                 ..
             } => {
                 if specs.len() > 1 && !features.is_empty() {
-                    bail!("cannot specify features for more than one package");
+                    failure::bail!("cannot specify features for more than one package");
                 }
                 members.extend(
                     ws.members()
@@ -241,7 +249,7 @@ pub fn resolve_with_previous<'cfg>(
                 // into the resolution graph.
                 if members.is_empty() {
                     if !(features.is_empty() && !all_features && uses_default_features) {
-                        bail!("cannot specify features for packages outside of workspace");
+                        failure::bail!("cannot specify features for packages outside of workspace");
                     }
                     members.extend(ws.members());
                 }
@@ -332,6 +340,24 @@ pub fn resolve_with_previous<'cfg>(
         warn,
     )?;
     resolved.register_used_patches(registry.patches());
+    if register_patches {
+        // It would be good if this warning was more targeted and helpful
+        // (such as showing close candidates that failed to match). However,
+        // that's not terribly easy to do, so just show a general help
+        // message.
+        let warnings: Vec<String> = resolved
+            .unused_patches()
+            .iter()
+            .map(|pkgid| format!("Patch `{}` was not used in the crate graph.", pkgid))
+            .collect();
+        if !warnings.is_empty() {
+            ws.config().shell().warn(format!(
+                "{}\n{}",
+                warnings.join("\n"),
+                UNUSED_PATCH_WARNING
+            ))?;
+        }
+    }
     if let Some(previous) = previous {
         resolved.merge_from(previous)?;
     }
@@ -397,10 +423,10 @@ pub fn get_resolved_packages<'a>(
 /// Note that this function, at the time of this writing, is basically the
 /// entire fix for #4127
 fn register_previous_locks(
-    ws: &Workspace,
-    registry: &mut PackageRegistry,
+    ws: &Workspace<'_>,
+    registry: &mut PackageRegistry<'_>,
     resolve: &Resolve,
-    keep: &Fn(&PackageId) -> bool,
+    keep: &dyn Fn(&PackageId) -> bool,
 ) {
     let path_pkg = |id: SourceId| {
         if !id.is_path() {
@@ -445,6 +471,7 @@ fn register_previous_locks(
     // package's dependencies here as that'll be covered below to poison those
     // if they changed.
     let mut avoid_locking = HashSet::new();
+    registry.add_to_yanked_whitelist(resolve.iter().filter(keep));
     for node in resolve.iter() {
         if !keep(&node) {
             add_deps(resolve, node, &mut avoid_locking);
