@@ -1,15 +1,16 @@
 use std::fmt::{self, Debug, Formatter};
 
+use log::trace;
 use url::Url;
 
-use core::source::{MaybePackage, Source, SourceId};
-use core::GitReference;
-use core::{Dependency, Package, PackageId, Summary};
-use sources::git::utils::{GitRemote, GitRevision};
-use sources::PathSource;
-use util::errors::CargoResult;
-use util::hex::short_hash;
-use util::Config;
+use crate::core::source::{MaybePackage, Source, SourceId};
+use crate::core::GitReference;
+use crate::core::{Dependency, Package, PackageId, Summary};
+use crate::sources::git::utils::{GitRemote, GitRevision};
+use crate::sources::PathSource;
+use crate::util::errors::CargoResult;
+use crate::util::hex::short_hash;
+use crate::util::Config;
 
 pub struct GitSource<'cfg> {
     remote: GitRemote,
@@ -77,7 +78,7 @@ pub fn canonicalize_url(url: &Url) -> CargoResult<Url> {
     // cannot-be-a-base-urls are not supported
     // eg. github.com:rust-lang-nursery/rustfmt.git
     if url.cannot_be_a_base() {
-        bail!(
+        failure::bail!(
             "invalid url `{}`: cannot-be-a-base-URLs are not supported",
             url
         )
@@ -113,7 +114,7 @@ pub fn canonicalize_url(url: &Url) -> CargoResult<Url> {
 }
 
 impl<'cfg> Debug for GitSource<'cfg> {
-    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         write!(f, "git repo at {}", self.remote.url())?;
 
         match self.reference.pretty_ref() {
@@ -124,7 +125,7 @@ impl<'cfg> Debug for GitSource<'cfg> {
 }
 
 impl<'cfg> Source for GitSource<'cfg> {
-    fn query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()> {
+    fn query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         let src = self
             .path_source
             .as_mut()
@@ -132,7 +133,7 @@ impl<'cfg> Source for GitSource<'cfg> {
         src.query(dep, f)
     }
 
-    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut FnMut(Summary)) -> CargoResult<()> {
+    fn fuzzy_query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         let src = self
             .path_source
             .as_mut()
@@ -161,7 +162,7 @@ impl<'cfg> Source for GitSource<'cfg> {
         let db_path = lock.parent().join("db").join(&self.ident);
 
         if self.config.cli_unstable().offline && !db_path.exists() {
-            bail!(
+            failure::bail!(
                 "can't checkout from '{}': you are in the offline mode (-Z offline)",
                 self.remote.url()
             );
@@ -237,13 +238,15 @@ impl<'cfg> Source for GitSource<'cfg> {
     fn describe(&self) -> String {
         format!("git repository {}", self.source_id)
     }
+
+    fn add_to_yanked_whitelist(&mut self, _pkgs: &[PackageId]) {}
 }
 
 #[cfg(test)]
 mod test {
     use super::ident;
+    use crate::util::ToUrl;
     use url::Url;
-    use util::ToUrl;
 
     #[test]
     pub fn test_url_to_path_ident_with_path() {
