@@ -3,12 +3,12 @@ use std::ffi::{OsStr, OsString};
 use std::fs::{self, File, OpenOptions};
 use std::io;
 use std::io::prelude::*;
-use std::path::{Component, Path, PathBuf};
 use std::iter;
+use std::path::{Component, Path, PathBuf};
 
 use filetime::FileTime;
 
-use util::errors::{CargoError, CargoResult, CargoResultExt, Internal};
+use crate::util::errors::{CargoResult, CargoResultExt, Internal};
 
 pub fn join_paths<T: AsRef<OsStr>>(paths: &[T], env: &str) -> CargoResult<OsString> {
     let err = match env::join_paths(paths.iter()) {
@@ -16,9 +16,12 @@ pub fn join_paths<T: AsRef<OsStr>>(paths: &[T], env: &str) -> CargoResult<OsStri
         Err(e) => e,
     };
     let paths = paths.iter().map(Path::new).collect::<Vec<_>>();
-    let err = CargoError::from(err);
-    let explain = Internal::new(format_err!("failed to join path array: {:?}", paths));
-    let err = CargoError::from(err.context(explain));
+    let err = failure::Error::from(err);
+    let explain = Internal::new(failure::format_err!(
+        "failed to join path array: {:?}",
+        paths
+    ));
+    let err = failure::Error::from(err.context(explain));
     let more_explain = format!(
         "failed to join search paths together\n\
          Does ${} have an unterminated quote character?",
@@ -31,7 +34,22 @@ pub fn dylib_path_envvar() -> &'static str {
     if cfg!(windows) {
         "PATH"
     } else if cfg!(target_os = "macos") {
-        "DYLD_LIBRARY_PATH"
+        // When loading and linking a dynamic library or bundle, dlopen
+        // searches in LD_LIBRARY_PATH, DYLD_LIBRARY_PATH, PWD, and
+        // DYLD_FALLBACK_LIBRARY_PATH.
+        // In the Mach-O format, a dynamic library has an "install path."
+        // Clients linking against the library record this path, and the
+        // dynamic linker, dyld, uses it to locate the library.
+        // dyld searches DYLD_LIBRARY_PATH *before* the install path.
+        // dyld searches DYLD_FALLBACK_LIBRARY_PATH only if it cannot
+        // find the library in the install path.
+        // Setting DYLD_LIBRARY_PATH can easily have unintended
+        // consequences.
+        //
+        // Also, DYLD_LIBRARY_PATH appears to have significant performance
+        // penalty starting in 10.13. Cargo's testsuite ran more than twice as
+        // slow with it on CI.
+        "DYLD_FALLBACK_LIBRARY_PATH"
     } else {
         "LD_LIBRARY_PATH"
     }
@@ -87,7 +105,7 @@ pub fn without_prefix<'a>(long_path: &'a Path, prefix: &'a Path) -> Option<&'a P
 
 pub fn resolve_executable(exec: &Path) -> CargoResult<PathBuf> {
     if exec.components().count() == 1 {
-        let paths = env::var_os("PATH").ok_or_else(|| format_err!("no PATH"))?;
+        let paths = env::var_os("PATH").ok_or_else(|| failure::format_err!("no PATH"))?;
         let candidates = env::split_paths(&paths).flat_map(|path| {
             let candidate = path.join(&exec);
             let with_exe = if env::consts::EXE_EXTENSION == "" {
@@ -105,7 +123,7 @@ pub fn resolve_executable(exec: &Path) -> CargoResult<PathBuf> {
             }
         }
 
-        bail!("no executable for `{}` found in PATH", exec.display())
+        failure::bail!("no executable for `{}` found in PATH", exec.display())
     } else {
         Ok(exec.canonicalize()?)
     }
@@ -114,7 +132,7 @@ pub fn resolve_executable(exec: &Path) -> CargoResult<PathBuf> {
 pub fn read(path: &Path) -> CargoResult<String> {
     match String::from_utf8(read_bytes(path)?) {
         Ok(s) => Ok(s),
-        Err(_) => bail!("path at `{}` was not valid utf-8", path.display()),
+        Err(_) => failure::bail!("path at `{}` was not valid utf-8", path.display()),
     }
 }
 
@@ -128,7 +146,7 @@ pub fn read_bytes(path: &Path) -> CargoResult<Vec<u8>> {
         f.read_to_end(&mut ret)?;
         Ok(ret)
     })()
-        .chain_err(|| format!("failed to read `{}`", path.display()))?;
+    .chain_err(|| format!("failed to read `{}`", path.display()))?;
     Ok(res)
 }
 
@@ -138,7 +156,7 @@ pub fn write(path: &Path, contents: &[u8]) -> CargoResult<()> {
         f.write_all(contents)?;
         Ok(())
     })()
-        .chain_err(|| format!("failed to write `{}`", path.display()))?;
+    .chain_err(|| format!("failed to write `{}`", path.display()))?;
     Ok(())
 }
 
@@ -159,7 +177,7 @@ pub fn write_if_changed<P: AsRef<Path>, C: AsRef<[u8]>>(path: P, contents: C) ->
         }
         Ok(())
     })()
-        .chain_err(|| format!("failed to write `{}`", path.as_ref().display()))?;
+    .chain_err(|| format!("failed to write `{}`", path.as_ref().display()))?;
     Ok(())
 }
 
@@ -174,7 +192,7 @@ pub fn append(path: &Path, contents: &[u8]) -> CargoResult<()> {
         f.write_all(contents)?;
         Ok(())
     })()
-        .chain_err(|| format!("failed to write `{}`", path.display()))?;
+    .chain_err(|| format!("failed to write `{}`", path.display()))?;
     Ok(())
 }
 
@@ -183,6 +201,18 @@ pub fn mtime(path: &Path) -> CargoResult<FileTime> {
     Ok(FileTime::from_last_modification_time(&meta))
 }
 
+/// get `FileTime::from_system_time(SystemTime::now());` using the exact clock that this file system is using.
+pub fn get_current_filesystem_time(path: &Path) -> CargoResult<FileTime> {
+    // note that if `FileTime::from_system_time(SystemTime::now());` is determined to be sufficient,
+    // then this can be removed.
+    let timestamp = path.with_file_name("invoked.timestamp");
+    write(
+        &timestamp,
+        b"This file has an mtime of when this was started.",
+    )?;
+    Ok(mtime(&timestamp)?)
+}
+
 #[cfg(unix)]
 pub fn path2bytes(path: &Path) -> CargoResult<&[u8]> {
     use std::os::unix::prelude::*;
@@ -192,14 +222,17 @@ pub fn path2bytes(path: &Path) -> CargoResult<&[u8]> {
 pub fn path2bytes(path: &Path) -> CargoResult<&[u8]> {
     match path.as_os_str().to_str() {
         Some(s) => Ok(s.as_bytes()),
-        None => Err(format_err!("invalid non-unicode path: {}", path.display())),
+        None => Err(failure::format_err!(
+            "invalid non-unicode path: {}",
+            path.display()
+        )),
     }
 }
 
 #[cfg(unix)]
 pub fn bytes2path(bytes: &[u8]) -> CargoResult<PathBuf> {
-    use std::os::unix::prelude::*;
     use std::ffi::OsStr;
+    use std::os::unix::prelude::*;
     Ok(PathBuf::from(OsStr::from_bytes(bytes)))
 }
 #[cfg(windows)]
@@ -207,11 +240,11 @@ pub fn bytes2path(bytes: &[u8]) -> CargoResult<PathBuf> {
     use std::str;
     match str::from_utf8(bytes) {
         Ok(s) => Ok(PathBuf::from(s)),
-        Err(..) => Err(format_err!("invalid non-unicode path")),
+        Err(..) => Err(failure::format_err!("invalid non-unicode path")),
     }
 }
 
-pub fn ancestors(path: &Path) -> PathAncestors {
+pub fn ancestors(path: &Path) -> PathAncestors<'_> {
     PathAncestors::new(path)
 }
 
@@ -221,7 +254,7 @@ pub struct PathAncestors<'a> {
 }
 
 impl<'a> PathAncestors<'a> {
-    fn new(path: &Path) -> PathAncestors {
+    fn new(path: &Path) -> PathAncestors<'_> {
         PathAncestors {
             current: Some(path),
             //HACK: avoid reading `~/.cargo/config` when testing Cargo itself.
@@ -258,7 +291,8 @@ fn _remove_dir_all(p: &Path) -> CargoResult<()> {
     if p.symlink_metadata()?.file_type().is_symlink() {
         return remove_file(p);
     }
-    let entries = p.read_dir()
+    let entries = p
+        .read_dir()
         .chain_err(|| format!("failed to read directory `{}`", p.display()))?;
     for entry in entries {
         let entry = entry?;
