@@ -9,7 +9,7 @@ use failure::Fail;
 use jobserver::Client;
 use shell_escape::escape;
 
-use util::{process_error, CargoResult, CargoResultExt, read2};
+use crate::util::{process_error, read2, CargoResult, CargoResultExt};
 
 /// A builder object for an external process, similar to `std::process::Command`.
 #[derive(Clone, Debug)]
@@ -27,11 +27,28 @@ pub struct ProcessBuilder {
     ///
     /// [jobserver_docs]: https://docs.rs/jobserver/0.1.6/jobserver/
     jobserver: Option<Client>,
+    /// Whether to include environment variable in display
+    display_env_vars: bool
 }
 
 impl fmt::Display for ProcessBuilder {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "`{}", self.program.to_string_lossy())?;
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "`")?;
+
+        if self.display_env_vars {
+            for (key, val) in self.env.iter() {
+                if let Some(val) = val {
+                    let val = escape(val.to_string_lossy());
+                    if cfg!(windows) {
+                        write!(f, "set {}={}&& ", key, val)?;
+                    } else {
+                        write!(f, "{}={} ", key, val)?;
+                    }
+                }
+            }
+        }
+
+        write!(f, "{}", self.program.to_string_lossy())?;
 
         for arg in &self.args {
             write!(f, " {}", escape(arg.to_string_lossy()))?;
@@ -129,15 +146,17 @@ impl ProcessBuilder {
         self
     }
 
+    /// Enable environment variable display
+    pub fn display_env_vars(&mut self) -> &mut Self {
+        self.display_env_vars = true;
+        self
+    }
+
     /// Run the process, waiting for completion, and mapping non-success exit codes to an error.
     pub fn exec(&self) -> CargoResult<()> {
         let mut command = self.build_command();
         let exit = command.status().chain_err(|| {
-            process_error(
-                &format!("could not execute process {}", self),
-                None,
-                None,
-            )
+            process_error(&format!("could not execute process {}", self), None, None)
         })?;
 
         if exit.success() {
@@ -147,7 +166,8 @@ impl ProcessBuilder {
                 &format!("process didn't exit successfully: {}", self),
                 Some(exit),
                 None,
-            ).into())
+            )
+            .into())
         }
     }
 
@@ -175,11 +195,7 @@ impl ProcessBuilder {
         let mut command = self.build_command();
 
         let output = command.output().chain_err(|| {
-            process_error(
-                &format!("could not execute process {}", self),
-                None,
-                None,
-            )
+            process_error(&format!("could not execute process {}", self), None, None)
         })?;
 
         if output.status.success() {
@@ -189,7 +205,8 @@ impl ProcessBuilder {
                 &format!("process didn't exit successfully: {}", self),
                 Some(output.status),
                 Some(&output),
-            ).into())
+            )
+            .into())
         }
     }
 
@@ -201,8 +218,8 @@ impl ProcessBuilder {
     /// Optionally, output can be passed to errors using `print_output`
     pub fn exec_with_streaming(
         &self,
-        on_stdout_line: &mut FnMut(&str) -> CargoResult<()>,
-        on_stderr_line: &mut FnMut(&str) -> CargoResult<()>,
+        on_stdout_line: &mut dyn FnMut(&str) -> CargoResult<()>,
+        on_stderr_line: &mut dyn FnMut(&str) -> CargoResult<()>,
         capture_output: bool,
     ) -> CargoResult<Output> {
         let mut stdout = Vec::new();
@@ -227,7 +244,8 @@ impl ProcessBuilder {
                         None => return,
                     }
                 };
-                { // scope for new_lines
+                {
+                    // scope for new_lines
                     let new_lines = if capture_output {
                         let dst = if is_out { &mut stdout } else { &mut stderr };
                         let start = dst.len();
@@ -257,13 +275,7 @@ impl ProcessBuilder {
             })?;
             child.wait()
         })()
-            .chain_err(|| {
-            process_error(
-                &format!("could not execute process {}", self),
-                None,
-                None,
-            )
-        })?;
+        .chain_err(|| process_error(&format!("could not execute process {}", self), None, None))?;
         let output = Output {
             stdout,
             stderr,
@@ -327,19 +339,20 @@ pub fn process<T: AsRef<OsStr>>(cmd: T) -> ProcessBuilder {
         cwd: None,
         env: HashMap::new(),
         jobserver: None,
+        display_env_vars: false,
     }
 }
 
 #[cfg(unix)]
 mod imp {
-    use CargoResult;
+    use crate::util::{process_error, ProcessBuilder};
+    use crate::CargoResult;
     use std::os::unix::process::CommandExt;
-    use util::{process_error, ProcessBuilder};
 
     pub fn exec_replace(process_builder: &ProcessBuilder) -> CargoResult<()> {
         let mut command = process_builder.build_command();
         let error = command.exec();
-        Err(::util::CargoError::from(error)
+        Err(failure::Error::from(error)
             .context(process_error(
                 &format!("could not execute process {}", process_builder),
                 None,
@@ -351,12 +364,10 @@ mod imp {
 
 #[cfg(windows)]
 mod imp {
-    extern crate winapi;
-
-    use CargoResult;
-    use util::{process_error, ProcessBuilder};
-    use self::winapi::shared::minwindef::{BOOL, DWORD, FALSE, TRUE};
-    use self::winapi::um::consoleapi::SetConsoleCtrlHandler;
+    use crate::util::{process_error, ProcessBuilder};
+    use crate::CargoResult;
+    use winapi::shared::minwindef::{BOOL, DWORD, FALSE, TRUE};
+    use winapi::um::consoleapi::SetConsoleCtrlHandler;
 
     unsafe extern "system" fn ctrlc_handler(_: DWORD) -> BOOL {
         // Do nothing. Let the child process handle it.
@@ -366,10 +377,7 @@ mod imp {
     pub fn exec_replace(process_builder: &ProcessBuilder) -> CargoResult<()> {
         unsafe {
             if SetConsoleCtrlHandler(Some(ctrlc_handler), TRUE) == FALSE {
-                return Err(process_error(
-                    "Could not set Ctrl-C handler.",
-                    None,
-                    None).into());
+                return Err(process_error("Could not set Ctrl-C handler.", None, None).into());
             }
         }
 
