@@ -1,5 +1,5 @@
-use support::registry::Package;
-use support::{basic_bin_manifest, basic_manifest, main_file, project};
+use crate::support::registry::Package;
+use crate::support::{basic_bin_manifest, basic_manifest, main_file, project};
 
 #[test]
 fn cargo_build_plan_simple() {
@@ -28,12 +28,14 @@ fn cargo_build_plan_simple() {
                 "package_name": "foo",
                 "package_version": "0.5.0",
                 "program": "rustc",
-                "target_kind": ["bin"]
+                "target_kind": ["bin"],
+                "compile_mode": "build"
             }
         ]
     }
     "#,
-        ).run();
+        )
+        .run();
     assert!(!p.bin("foo").is_file());
 }
 
@@ -51,7 +53,8 @@ fn cargo_build_plan_single_dep() {
             [dependencies]
             bar = { path = "bar" }
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
             extern crate bar;
@@ -60,7 +63,8 @@ fn cargo_build_plan_single_dep() {
             #[test]
             fn test() { foo(); }
         "#,
-        ).file("bar/Cargo.toml", &basic_manifest("bar", "0.0.1"))
+        )
+        .file("bar/Cargo.toml", &basic_manifest("bar", "0.0.1"))
         .file("bar/src/lib.rs", "pub fn bar() {}")
         .build();
     p.cargo("build --build-plan -Zunstable-options")
@@ -86,7 +90,8 @@ fn cargo_build_plan_single_dep() {
                 "package_name": "bar",
                 "package_version": "0.0.1",
                 "program": "rustc",
-                "target_kind": ["lib"]
+                "target_kind": ["lib"],
+                "compile_mode": "build"
             },
             {
                 "args": "{...}",
@@ -101,12 +106,14 @@ fn cargo_build_plan_single_dep() {
                 "package_name": "foo",
                 "package_version": "0.5.0",
                 "program": "rustc",
-                "target_kind": ["lib"]
+                "target_kind": ["lib"],
+                "compile_mode": "build"
             }
         ]
     }
     "#,
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -122,7 +129,8 @@ fn cargo_build_plan_build_script() {
             authors = ["wycats@example.com"]
             build = "build.rs"
         "#,
-        ).file("src/main.rs", r#"fn main() {}"#)
+        )
+        .file("src/main.rs", r#"fn main() {}"#)
         .file("build.rs", r#"fn main() {}"#)
         .build();
 
@@ -148,7 +156,8 @@ fn cargo_build_plan_build_script() {
                 "package_name": "foo",
                 "package_version": "0.5.0",
                 "program": "rustc",
-                "target_kind": ["custom-build"]
+                "target_kind": ["custom-build"],
+                "compile_mode": "build"
             },
             {
                 "args": "{...}",
@@ -161,7 +170,8 @@ fn cargo_build_plan_build_script() {
                 "package_name": "foo",
                 "package_version": "0.5.0",
                 "program": "[..]/build-script-build",
-                "target_kind": ["custom-build"]
+                "target_kind": ["custom-build"],
+                "compile_mode": "run-custom-build"
             },
             {
                 "args": "{...}",
@@ -174,12 +184,14 @@ fn cargo_build_plan_build_script() {
                 "package_name": "foo",
                 "package_version": "0.5.0",
                 "program": "rustc",
-                "target_kind": ["bin"]
+                "target_kind": ["bin"],
+                "compile_mode": "build"
             }
         ]
     }
     "#,
-        ).run();
+        )
+        .run();
 }
 
 #[test]
