@@ -1,10 +1,10 @@
 use std::fmt::{self, Write};
 
+use crate::support::install::exe;
+use crate::support::paths::CargoPathExt;
+use crate::support::registry::Package;
+use crate::support::{basic_manifest, project};
 use glob::glob;
-use support::install::exe;
-use support::paths::CargoPathExt;
-use support::registry::Package;
-use support::{basic_manifest, project};
 
 #[test]
 fn check_success() {
@@ -20,10 +20,12 @@ fn check_success() {
             [dependencies.bar]
             path = "../bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate bar; fn main() { ::bar::baz(); }",
-        ).build();
+        )
+        .build();
     let _bar = project()
         .at("bar")
         .file("Cargo.toml", &basic_manifest("bar", "0.1.0"))
@@ -47,17 +49,22 @@ fn check_fail() {
             [dependencies.bar]
             path = "../bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate bar; fn main() { ::bar::baz(42); }",
-        ).build();
+        )
+        .build();
     let _bar = project()
         .at("bar")
         .file("Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("src/lib.rs", "pub fn baz() {}")
         .build();
 
-    foo.cargo("check").with_status(101).run();
+    foo.cargo("check")
+        .with_status(101)
+        .with_stderr_contains("[..]this function takes 0 parameters but 1 parameter was supplied")
+        .run();
 }
 
 #[test]
@@ -74,7 +81,8 @@ fn custom_derive() {
             [dependencies.bar]
             path = "../bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             r#"
 #[macro_use]
@@ -92,7 +100,8 @@ fn main() {
     a.b();
 }
 "#,
-        ).build();
+        )
+        .build();
     let _bar = project()
         .at("bar")
         .file(
@@ -105,7 +114,8 @@ fn main() {
             [lib]
             proc-macro = true
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
 extern crate proc_macro;
@@ -117,7 +127,8 @@ pub fn derive(_input: TokenStream) -> TokenStream {
     format!("impl B for A {{ fn b(&self) {{}} }}").parse().unwrap()
 }
 "#,
-        ).build();
+        )
+        .build();
 
     foo.cargo("check").run();
 }
@@ -136,10 +147,12 @@ fn check_build() {
             [dependencies.bar]
             path = "../bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate bar; fn main() { ::bar::baz(); }",
-        ).build();
+        )
+        .build();
 
     let _bar = project()
         .at("bar")
@@ -165,10 +178,12 @@ fn build_check() {
             [dependencies.bar]
             path = "../bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate bar; fn main() { ::bar::baz(); }",
-        ).build();
+        )
+        .build();
 
     let _bar = project()
         .at("bar")
@@ -210,7 +225,8 @@ fn issue_3419() {
             [dependencies]
             rustc-serialize = "*"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
             extern crate rustc_serialize;
@@ -219,7 +235,8 @@ fn issue_3419() {
 
             pub fn take<T: Decodable>() {}
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             r#"
             extern crate rustc_serialize;
@@ -233,7 +250,8 @@ fn issue_3419() {
                 foo::take::<Foo>();
             }
         "#,
-        ).build();
+        )
+        .build();
 
     Package::new("rustc-serialize", "1.0.0")
         .file(
@@ -247,7 +265,8 @@ fn issue_3419() {
                                          -> Result<T, Self::Error>
                     where F: FnOnce(&mut Self) -> Result<T, Self::Error>;
                  } "#,
-        ).publish();
+        )
+        .publish();
 
     p.cargo("check").run();
 }
@@ -269,7 +288,8 @@ fn dylib_check_preserves_build_cache() {
 
             [dependencies]
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     p.cargo("build")
@@ -278,7 +298,8 @@ fn dylib_check_preserves_build_cache() {
 [..]Compiling foo v0.1.0 ([..])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 ",
-        ).run();
+        )
+        .run();
 
     p.cargo("check").run();
 
@@ -302,10 +323,12 @@ fn rustc_check() {
             [dependencies.bar]
             path = "../bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate bar; fn main() { ::bar::baz(); }",
-        ).build();
+        )
+        .build();
     let _bar = project()
         .at("bar")
         .file("Cargo.toml", &basic_manifest("bar", "0.1.0"))
@@ -329,10 +352,12 @@ fn rustc_check_err() {
             [dependencies.bar]
             path = "../bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate bar; fn main() { ::bar::qux(); }",
-        ).build();
+        )
+        .build();
     let _bar = project()
         .at("bar")
         .file("Cargo.toml", &basic_manifest("bar", "0.1.0"))
@@ -341,6 +366,9 @@ fn rustc_check_err() {
 
     foo.cargo("rustc --profile check -- --emit=metadata")
         .with_status(101)
+        .with_stderr_contains("[CHECKING] bar [..]")
+        .with_stderr_contains("[CHECKING] foo [..]")
+        .with_stderr_contains("[..]cannot find function `qux` in module `bar`")
         .run();
 }
 
@@ -359,7 +387,8 @@ fn check_all() {
             [dependencies]
             b = { path = "b" }
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .file("examples/a.rs", "fn main() {}")
         .file("tests/a.rs", "")
         .file("src/lib.rs", "")
@@ -385,7 +414,8 @@ fn check_virtual_all_implied() {
             [workspace]
             members = ["bar", "baz"]
         "#,
-        ).file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
+        )
+        .file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("bar/src/lib.rs", "pub fn bar() {}")
         .file("baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
         .file("baz/src/lib.rs", "pub fn baz() {}")
@@ -449,7 +479,8 @@ fn check_unit_test_profile() {
                 }
             }
         "#,
-        ).build();
+        )
+        .build();
 
     foo.cargo("check").run();
     foo.cargo("check --profile test")
@@ -471,7 +502,8 @@ fn check_filters() {
                 fn unused_unit_lib() {}
             }
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             r#"
             fn main() {}
@@ -481,7 +513,8 @@ fn check_filters() {
                 fn unused_unit_bin() {}
             }
         "#,
-        ).file(
+        )
+        .file(
             "tests/t1.rs",
             r#"
             fn unused_normal_t1() {}
@@ -490,7 +523,8 @@ fn check_filters() {
                 fn unused_unit_t1() {}
             }
         "#,
-        ).file(
+        )
+        .file(
             "examples/ex1.rs",
             r#"
             fn main() {}
@@ -500,7 +534,8 @@ fn check_filters() {
                 fn unused_unit_ex1() {}
             }
         "#,
-        ).file(
+        )
+        .file(
             "benches/b1.rs",
             r#"
             fn unused_normal_b1() {}
@@ -509,7 +544,8 @@ fn check_filters() {
                 fn unused_unit_b1() {}
             }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("check")
         .with_stderr_contains("[..]unused_normal_lib[..]")
@@ -615,12 +651,11 @@ fn check_artifacts() {
     p.cargo("check --example ex1").run();
     assert!(!p.root().join("target/debug/libfoo.rmeta").is_file());
     assert!(!p.root().join("target/debug/libfoo.rlib").is_file());
-    assert!(
-        !p.root()
-            .join("target/debug/examples")
-            .join(exe("ex1"))
-            .is_file()
-    );
+    assert!(!p
+        .root()
+        .join("target/debug/examples")
+        .join(exe("ex1"))
+        .is_file());
     assert_glob("target/debug/deps/libfoo-*.rmeta", 1);
     assert_glob("target/debug/examples/libex1-*.rmeta", 1);
 
@@ -647,7 +682,8 @@ src/lib.rs:1:27: error[E0308]: mismatched types
 error: aborting due to previous error
 error: Could not compile `foo`.
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -663,7 +699,8 @@ fn proc_macro() {
                 [lib]
                 proc-macro = true
             "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             r#"
                 extern crate proc_macro;
@@ -675,7 +712,8 @@ fn proc_macro() {
                     "".parse().unwrap()
                 }
             "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             r#"
                 #[macro_use]
@@ -686,7 +724,8 @@ fn proc_macro() {
 
                 fn main() {}
             "#,
-        ).build();
+        )
+        .build();
     p.cargo("check -v").env("RUST_LOG", "cargo=trace").run();
 }
 
