@@ -1,15 +1,16 @@
-use cargo::core::Shell;
-use cargo::util::config::{self, Config};
-use cargo::util::toml::{self, VecStringOrBool as VSOB};
-use cargo::CargoError;
-use cargotest::support::{execs, lines_match, paths, project};
-use hamcrest::assert_that;
+use std::borrow::Borrow;
 use std::collections;
 use std::fs;
 
+use crate::support::{lines_match, paths, project};
+use cargo::core::{enable_nightly_features, Shell};
+use cargo::util::config::{self, Config};
+use cargo::util::toml::{self, VecStringOrBool as VSOB};
+use serde::Deserialize;
+
 #[test]
 fn read_env_vars_for_config() {
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -32,10 +33,7 @@ fn read_env_vars_for_config() {
         )
         .build();
 
-    assert_that(
-        p.cargo("build").env("CARGO_BUILD_JOBS", "100"),
-        execs().with_status(0),
-    );
+    p.cargo("build").env("CARGO_BUILD_JOBS", "100").run();
 }
 
 fn write_config(config: &str) {
@@ -45,6 +43,7 @@ fn write_config(config: &str) {
 }
 
 fn new_config(env: &[(&str, &str)]) -> Config {
+    enable_nightly_features(); // -Z advanced-env
     let output = Box::new(fs::File::create(paths::root().join("shell.out")).unwrap());
     let shell = Shell::from_write(output);
     let cwd = paths::root();
@@ -55,21 +54,24 @@ fn new_config(env: &[(&str, &str)]) -> Config {
         .collect();
     let mut config = Config::new(shell, cwd, homedir);
     config.set_env(env);
-    config.configure(
-        0,
-        None,
-        &None,
-        false,
-        false,
-        &None,
-        &["advanced-env".into()],
-    ).unwrap();
+    config
+        .configure(
+            0,
+            None,
+            &None,
+            false,
+            false,
+            &None,
+            &["advanced-env".into()],
+        )
+        .unwrap();
     config
 }
 
-fn assert_error(error: CargoError, msgs: &str) {
+fn assert_error<E: Borrow<failure::Error>>(error: E, msgs: &str) {
     let causes = error
-        .causes()
+        .borrow()
+        .iter_chain()
         .map(|e| e.to_string())
         .collect::<Vec<_>>()
         .join("\n");
@@ -131,7 +133,7 @@ unused = 456
     let path = paths::root().join("shell.out");
     let output = fs::read_to_string(path).unwrap();
     let expected = "\
-warning: unused key `S.unused` in config file `[..][/].cargo[/]config`
+warning: unused key `S.unused` in config file `[..]/.cargo/config`
 ";
     if !lines_match(expected, &output) {
         panic!(
@@ -293,7 +295,7 @@ opt-level = 'foo'
 
     assert_error(
         config.get::<toml::TomlProfile>("profile.dev").unwrap_err(),
-        "error in [..][/].cargo[/]config: \
+        "error in [..]/.cargo/config: \
          could not load config key `profile.dev.opt-level`: \
          must be an integer, `z`, or `s`, but found: foo",
     );
@@ -366,11 +368,11 @@ big = 123456789
     );
     assert_error(
         config.get::<i64>("S.f2").unwrap_err(),
-        "error in [..][/].cargo[/]config: `S.f2` expected an integer, but found a string",
+        "error in [..]/.cargo/config: `S.f2` expected an integer, but found a string",
     );
     assert_error(
         config.get::<u8>("S.big").unwrap_err(),
-        "error in [..].cargo[/]config: could not load config key `S.big`: \
+        "error in [..].cargo/config: could not load config key `S.big`: \
          invalid value: integer `123456789`, expected u8",
     );
 
@@ -426,7 +428,7 @@ fn config_bad_toml() {
         "\
 could not load Cargo configuration
 Caused by:
-  could not parse TOML configuration in `[..][/].cargo[/]config`
+  could not parse TOML configuration in `[..]/.cargo/config`
 Caused by:
   could not parse input as TOML
 Caused by:
@@ -476,7 +478,7 @@ l = ['y']
         config.get::<L>("l3").unwrap_err(),
         "\
 invalid configuration for key `l3`
-expected a list, but found a integer for `l3` in [..][/].cargo[/]config",
+expected a list, but found a integer for `l3` in [..]/.cargo/config",
     );
     assert_eq!(
         config.get::<L>("l4").unwrap(),
@@ -648,14 +650,26 @@ i64max = 9223372036854775807
         ("CARGO_EI64MAX", "9223372036854775807"),
     ]);
 
-    assert_eq!(config.get::<u64>("i64max").unwrap(), 9223372036854775807);
-    assert_eq!(config.get::<i64>("i64max").unwrap(), 9223372036854775807);
-    assert_eq!(config.get::<u64>("ei64max").unwrap(), 9223372036854775807);
-    assert_eq!(config.get::<i64>("ei64max").unwrap(), 9223372036854775807);
+    assert_eq!(
+        config.get::<u64>("i64max").unwrap(),
+        9_223_372_036_854_775_807
+    );
+    assert_eq!(
+        config.get::<i64>("i64max").unwrap(),
+        9_223_372_036_854_775_807
+    );
+    assert_eq!(
+        config.get::<u64>("ei64max").unwrap(),
+        9_223_372_036_854_775_807
+    );
+    assert_eq!(
+        config.get::<i64>("ei64max").unwrap(),
+        9_223_372_036_854_775_807
+    );
 
     assert_error(
         config.get::<u32>("nneg").unwrap_err(),
-        "error in [..].cargo[/]config: \
+        "error in [..].cargo/config: \
          could not load config key `nneg`: \
          invalid value: integer `-123456789`, expected u32",
     );
@@ -667,7 +681,7 @@ i64max = 9223372036854775807
     );
     assert_error(
         config.get::<i8>("npos").unwrap_err(),
-        "error in [..].cargo[/]config: \
+        "error in [..].cargo/config: \
          could not load config key `npos`: \
          invalid value: integer `123456789`, expected i8",
     );
