@@ -1,14 +1,15 @@
-use serde_json;
 use std::collections::HashMap;
 use std::fs::{self, File};
 use std::io::prelude::*;
 use std::str;
 
-use support::cargo_process;
-use support::git;
-use support::paths;
-use support::registry::{cksum, Package};
-use support::{basic_manifest, project, ProjectBuilder};
+use serde::Serialize;
+
+use crate::support::cargo_process;
+use crate::support::git;
+use crate::support::paths;
+use crate::support::registry::{cksum, Package};
+use crate::support::{basic_manifest, project, ProjectBuilder};
 
 fn setup() {
     let root = paths::root();
@@ -93,10 +94,12 @@ fn simple() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             "extern crate bar; pub fn foo() { bar::bar(); }",
-        ).build();
+        )
+        .build();
 
     p.cargo("build")
         .with_stderr(
@@ -105,7 +108,8 @@ fn simple() {
 [COMPILING] foo v0.1.0 ([CWD])
 [FINISHED] [..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -128,10 +132,12 @@ fn simple_install() {
             [dependencies]
             foo = "0.0.1"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate foo; pub fn main() { foo::foo(); }",
-        ).build();
+        )
+        .build();
 
     cargo_process("install bar")
         .with_stderr(
@@ -142,7 +148,8 @@ fn simple_install() {
   Installing [..]bar[..]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -166,10 +173,12 @@ fn simple_install_fail() {
             foo = "0.1.0"
             baz = "9.8.7"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate foo; pub fn main() { foo::foo(); }",
-        ).build();
+        )
+        .build();
 
     cargo_process("install bar")
         .with_status(101)
@@ -183,7 +192,8 @@ location searched: registry `https://github.com/rust-lang/crates.io-index`
 did you mean: bar, foo
 required by package `bar v0.1.0`
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -210,10 +220,12 @@ fn install_without_feature_dep() {
             [features]
             wantbaz = ["baz"]
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "extern crate foo; pub fn main() { foo::foo(); }",
-        ).build();
+        )
+        .build();
 
     cargo_process("install bar")
         .with_stderr(
@@ -224,7 +236,8 @@ fn install_without_feature_dep() {
   Installing [..]bar[..]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -245,10 +258,12 @@ fn not_there() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             "extern crate bar; pub fn foo() { bar::bar(); }",
-        ).build();
+        )
+        .build();
 
     p.cargo("build")
         .with_status(101)
@@ -258,7 +273,8 @@ error: no matching package named `bar` found
 location searched: [..]
 required by package `foo v0.1.0 ([..])`
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -289,10 +305,12 @@ fn multiple() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             "extern crate bar; pub fn foo() { bar::bar(); }",
-        ).build();
+        )
+        .build();
 
     p.cargo("build")
         .with_stderr(
@@ -301,7 +319,8 @@ fn multiple() {
 [COMPILING] foo v0.1.0 ([CWD])
 [FINISHED] [..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -318,10 +337,12 @@ fn crates_io_then_directory() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file(
+        )
+        .file(
             "src/lib.rs",
             "extern crate bar; pub fn foo() { bar::bar(); }",
-        ).build();
+        )
+        .build();
 
     let cksum = Package::new("bar", "0.1.0")
         .file("src/lib.rs", "pub fn bar() -> u32 { 0 }")
@@ -331,12 +352,14 @@ fn crates_io_then_directory() {
         .with_stderr(
             "\
 [UPDATING] `[..]` index
-[DOWNLOADING] bar v0.1.0 ([..])
+[DOWNLOADING] crates ...
+[DOWNLOADED] bar v0.1.0 ([..])
 [COMPILING] bar v0.1.0
 [COMPILING] foo v0.1.0 ([CWD])
 [FINISHED] [..]
 ",
-        ).run();
+        )
+        .run();
 
     setup();
 
@@ -353,7 +376,8 @@ fn crates_io_then_directory() {
 [COMPILING] foo v0.1.0 ([CWD])
 [FINISHED] [..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -370,7 +394,8 @@ fn crates_io_then_bad_checksum() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     Package::new("bar", "0.1.0").publish();
@@ -398,7 +423,8 @@ this could be indicative of a few possible errors:
 unable to verify that `bar v0.1.0` is the same as when the lockfile was generated
 
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -425,7 +451,8 @@ fn bad_file_checksum() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     p.cargo("build")
@@ -440,7 +467,8 @@ directory sources are not intended to be edited, if modifications are \
 required then it is recommended that [replace] is used with a forked copy of \
 the source
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -468,7 +496,8 @@ fn only_dot_files_ok() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     p.cargo("build").run();
@@ -500,7 +529,8 @@ fn random_files_ok() {
             [dependencies]
             bar = "0.1.0"
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     p.cargo("build").run();
@@ -511,7 +541,8 @@ fn git_lock_file_doesnt_change() {
     let git = git::new("git", |p| {
         p.file("Cargo.toml", &basic_manifest("git", "0.5.0"))
             .file("src/lib.rs", "")
-    }).unwrap();
+    })
+    .unwrap();
 
     VendorPackage::new("git")
         .file("Cargo.toml", &basic_manifest("git", "0.5.0"))
@@ -534,7 +565,8 @@ fn git_lock_file_doesnt_change() {
         "#,
                 git.url()
             ),
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     p.cargo("build").run();
@@ -555,7 +587,8 @@ fn git_lock_file_doesnt_change() {
         directory = 'index'
     "#,
             git.url()
-        ).as_bytes()
+        )
+        .as_bytes()
     ));
 
     p.cargo("build")
@@ -565,7 +598,8 @@ fn git_lock_file_doesnt_change() {
 [COMPILING] [..]
 [FINISHED] [..]
 ",
-        ).run();
+        )
+        .run();
 
     let mut lock2 = String::new();
     t!(t!(File::open(p.root().join("Cargo.lock"))).read_to_string(&mut lock2));
@@ -592,7 +626,8 @@ fn git_override_requires_lockfile() {
             [dependencies]
             git = { git = 'https://example.com/' }
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .build();
 
     let root = paths::root();
@@ -625,7 +660,8 @@ remove the source replacement configuration, generate a lock file, and then
 restore the source replacement configuration to continue the build
 
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -642,7 +678,8 @@ fn workspace_different_locations() {
                 [dependencies]
                 baz = "*"
             "#,
-        ).file("foo/src/lib.rs", "")
+        )
+        .file("foo/src/lib.rs", "")
         .file("foo/vendor/baz/Cargo.toml", &basic_manifest("baz", "0.1.0"))
         .file("foo/vendor/baz/src/lib.rs", "")
         .file("foo/vendor/baz/.cargo-checksum.json", "{\"files\":{}}")
@@ -656,7 +693,8 @@ fn workspace_different_locations() {
                 [dependencies]
                 baz = "*"
             "#,
-        ).file("bar/src/lib.rs", "")
+        )
+        .file("bar/src/lib.rs", "")
         .file(
             ".cargo/config",
             r#"
@@ -669,7 +707,8 @@ fn workspace_different_locations() {
                 [source.my-awesome-local-registry]
                 directory = 'foo/vendor'
             "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("build").cwd(p.root().join("foo")).run();
     p.cargo("build")
@@ -680,5 +719,48 @@ fn workspace_different_locations() {
 [COMPILING] bar [..]
 [FINISHED] [..]
 ",
-        ).run();
+        )
+        .run();
+}
+
+#[test]
+fn version_missing() {
+    setup();
+
+    VendorPackage::new("foo")
+        .file("src/lib.rs", "pub fn foo() {}")
+        .build();
+
+    VendorPackage::new("bar")
+        .file(
+            "Cargo.toml",
+            r#"
+                [package]
+                name = "bar"
+                version = "0.1.0"
+                authors = []
+
+                [dependencies]
+                foo = "2"
+            "#,
+        )
+        .file("src/main.rs", "fn main() {}")
+        .build();
+
+    cargo_process("install bar")
+        .with_stderr(
+            "\
+[INSTALLING] bar v0.1.0
+error: failed to compile [..]
+
+Caused by:
+  failed to select a version for the requirement `foo = \"^2\"`
+  candidate versions found which didn't match: 0.0.1
+  location searched: directory source `[..] (which is replacing registry `[..]`)
+required by package `bar v0.1.0`
+perhaps a crate was updated and forgotten to be re-vendored?
+",
+        )
+        .with_status(101)
+        .run();
 }
