@@ -1,14 +1,14 @@
+use crate::support;
 use std::fs::{self, File, OpenOptions};
 use std::io::prelude::*;
-use support;
 
+use crate::support::cross_compile;
+use crate::support::git;
+use crate::support::install::{assert_has_installed_exe, assert_has_not_installed_exe, cargo_home};
+use crate::support::paths;
+use crate::support::registry::Package;
+use crate::support::{basic_manifest, cargo_process, project};
 use git2;
-use support::cross_compile;
-use support::git;
-use support::install::{assert_has_installed_exe, assert_has_not_installed_exe, cargo_home};
-use support::paths;
-use support::registry::Package;
-use support::{basic_manifest, cargo_process, project};
 
 fn pkg(name: &str, vers: &str) {
     Package::new(name, vers)
@@ -16,7 +16,8 @@ fn pkg(name: &str, vers: &str) {
         .file(
             "src/main.rs",
             &format!("extern crate {}; fn main() {{}}", name),
-        ).publish();
+        )
+        .publish();
 }
 
 #[test]
@@ -27,14 +28,16 @@ fn simple() {
         .with_stderr(
             "\
 [UPDATING] `[..]` index
-[DOWNLOADING] foo v0.0.1 (registry [..])
+[DOWNLOADING] crates ...
+[DOWNLOADED] foo v0.0.1 (registry [..])
 [INSTALLING] foo v0.0.1
 [COMPILING] foo v0.0.1
 [FINISHED] release [optimized] target(s) in [..]
 [INSTALLING] [CWD]/home/.cargo/bin/foo[EXE]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
     assert_has_installed_exe(cargo_home(), "foo");
 
     cargo_process("uninstall foo")
@@ -53,12 +56,14 @@ fn multiple_pkgs() {
         .with_stderr(
             "\
 [UPDATING] `[..]` index
-[DOWNLOADING] foo v0.0.1 (registry `[CWD]/registry`)
+[DOWNLOADING] crates ...
+[DOWNLOADED] foo v0.0.1 (registry `[CWD]/registry`)
 [INSTALLING] foo v0.0.1
 [COMPILING] foo v0.0.1
 [FINISHED] release [optimized] target(s) in [..]
 [INSTALLING] [CWD]/home/.cargo/bin/foo[EXE]
-[DOWNLOADING] bar v0.0.2 (registry `[CWD]/registry`)
+[DOWNLOADING] crates ...
+[DOWNLOADED] bar v0.0.2 (registry `[CWD]/registry`)
 [INSTALLING] bar v0.0.2
 [COMPILING] bar v0.0.2
 [FINISHED] release [optimized] target(s) in [..]
@@ -68,7 +73,8 @@ error: could not find `baz` in registry `[..]`
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 error: some crates failed to install
 ",
-        ).run();
+        )
+        .run();
     assert_has_installed_exe(cargo_home(), "foo");
     assert_has_installed_exe(cargo_home(), "bar");
 
@@ -79,7 +85,8 @@ error: some crates failed to install
 [REMOVING] [CWD]/home/.cargo/bin/bar[EXE]
 [SUMMARY] Successfully uninstalled foo, bar!
 ",
-        ).run();
+        )
+        .run();
 
     assert_has_not_installed_exe(cargo_home(), "foo");
     assert_has_not_installed_exe(cargo_home(), "bar");
@@ -97,14 +104,16 @@ fn pick_max_version() {
         .with_stderr(
             "\
 [UPDATING] `[..]` index
-[DOWNLOADING] foo v0.2.1 (registry [..])
+[DOWNLOADING] crates ...
+[DOWNLOADED] foo v0.2.1 (registry [..])
 [INSTALLING] foo v0.2.1
 [COMPILING] foo v0.2.1
 [FINISHED] release [optimized] target(s) in [..]
 [INSTALLING] [CWD]/home/.cargo/bin/foo[EXE]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
@@ -132,7 +141,8 @@ fn missing() {
 [UPDATING] [..] index
 [ERROR] could not find `bar` in registry `[..]`
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -145,7 +155,8 @@ fn bad_version() {
 [UPDATING] [..] index
 [ERROR] could not find `foo` in registry `[..]` with version `=0.2.0`
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -162,7 +173,8 @@ Caused by:
 Caused by:
   [..] (os error [..])
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -185,8 +197,10 @@ fn install_location_precedence() {
         root = '{}'
     ",
                 t3.display()
-            ).as_bytes(),
-        ).unwrap();
+            )
+            .as_bytes(),
+        )
+        .unwrap();
 
     println!("install --root");
 
@@ -233,7 +247,8 @@ fn install_path() {
 [ERROR] binary `foo[..]` already exists in destination as part of `foo v0.0.1 [..]`
 Add --force to overwrite
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -253,7 +268,8 @@ fn multiple_crates_error() {
 [UPDATING] git repository [..]
 [ERROR] multiple packages with binaries found: bar, foo
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -279,6 +295,31 @@ fn multiple_crates_select() {
     assert_has_installed_exe(cargo_home(), "bar");
 }
 
+#[test]
+fn multiple_crates_git_all() {
+    let p = git::repo(&paths::root().join("foo"))
+        .file(
+            "Cargo.toml",
+            r#"\
+[workspace]
+members = ["bin1", "bin2"]
+"#,
+        )
+        .file("bin1/Cargo.toml", &basic_manifest("bin1", "0.1.0"))
+        .file("bin2/Cargo.toml", &basic_manifest("bin2", "0.1.0"))
+        .file(
+            "bin1/src/main.rs",
+            r#"fn main() { println!("Hello, world!"); }"#,
+        )
+        .file(
+            "bin2/src/main.rs",
+            r#"fn main() { println!("Hello, world!"); }"#,
+        )
+        .build();
+
+    cargo_process(&format!("install --git {} bin1 bin2", p.url().to_string())).run();
+}
+
 #[test]
 fn multiple_crates_auto_binaries() {
     let p = project()
@@ -293,7 +334,8 @@ fn multiple_crates_auto_binaries() {
             [dependencies]
             bar = { path = "a" }
         "#,
-        ).file("src/main.rs", "extern crate bar; fn main() {}")
+        )
+        .file("src/main.rs", "extern crate bar; fn main() {}")
         .file("a/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("a/src/lib.rs", "")
         .build();
@@ -316,7 +358,8 @@ fn multiple_crates_auto_examples() {
             [dependencies]
             bar = { path = "a" }
         "#,
-        ).file("src/lib.rs", "extern crate bar;")
+        )
+        .file("src/lib.rs", "extern crate bar;")
         .file(
             "examples/foo.rs",
             "
@@ -324,7 +367,8 @@ fn multiple_crates_auto_examples() {
             extern crate foo;
             fn main() {}
         ",
-        ).file("a/Cargo.toml", &basic_manifest("bar", "0.1.0"))
+        )
+        .file("a/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("a/src/lib.rs", "")
         .build();
 
@@ -349,7 +393,8 @@ fn no_binaries_or_examples() {
             [dependencies]
             bar = { path = "a" }
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file("a/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("a/src/lib.rs", "")
         .build();
@@ -377,7 +422,8 @@ fn no_binaries() {
 [INSTALLING] foo [..]
 [ERROR] specified package has no binaries
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -412,7 +458,8 @@ fn install_twice() {
 binary `foo-bin2[..]` already exists in destination as part of `foo v0.0.1 ([..])`
 Add --force to overwrite
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -437,7 +484,8 @@ fn install_force() {
 [REPLACING] [CWD]/home/.cargo/bin/foo[EXE]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
 
     cargo_process("install --list")
         .with_stdout(
@@ -445,7 +493,8 @@ warning: be sure to add `[..]` to your PATH to be able to run the installed bina
 foo v0.2.0 ([..]):
     foo[..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -475,7 +524,8 @@ fn install_force_partial_overlap() {
 [REPLACING] [CWD]/home/.cargo/bin/foo-bin2[EXE]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
 
     cargo_process("install --list")
         .with_stdout(
@@ -486,7 +536,8 @@ foo v0.2.0 ([..]):
     foo-bin2[..]
     foo-bin3[..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -515,7 +566,8 @@ fn install_force_bin() {
 [REPLACING] [CWD]/home/.cargo/bin/foo-bin2[EXE]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
 
     cargo_process("install --list")
         .with_stdout(
@@ -525,7 +577,8 @@ foo v0.0.1 ([..]):
 foo v0.2.0 ([..]):
     foo-bin2[..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -545,7 +598,8 @@ Caused by:
 
 To learn more, run the command again with --verbose.
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -567,7 +621,8 @@ fn git_repo() {
 [INSTALLING] [CWD]/home/.cargo/bin/foo[EXE]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
     assert_has_installed_exe(cargo_home(), "foo");
     assert_has_installed_exe(cargo_home(), "foo");
 }
@@ -590,7 +645,8 @@ bar v0.2.1:
 foo v0.0.1:
     foo[..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -603,7 +659,8 @@ fn list_error() {
 foo v0.0.1:
     foo[..]
 ",
-        ).run();
+        )
+        .run();
     let mut worldfile_path = cargo_home();
     worldfile_path.push(".crates.toml");
     let mut worldfile = OpenOptions::new()
@@ -624,7 +681,8 @@ Caused by:
 Caused by:
   unexpected character[..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -694,10 +752,11 @@ fn installs_from_cwd_by_default() {
     p.cargo("install")
         .with_stderr_contains(
             "warning: Using `cargo install` to install the binaries for the \
-             project in current working directory is deprecated, \
+             package in current working directory is deprecated, \
              use `cargo install --path .` instead. \
              Use `cargo build` if you want to simply build the package.",
-        ).run();
+        )
+        .run();
     assert_has_installed_exe(cargo_home(), "foo");
 }
 
@@ -720,7 +779,8 @@ fn installs_from_cwd_with_2018_warnings() {
             authors = []
             edition = "2018"
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .build();
 
     p.cargo("install")
@@ -728,10 +788,11 @@ fn installs_from_cwd_with_2018_warnings() {
         .with_status(101)
         .with_stderr_contains(
             "error: Using `cargo install` to install the binaries for the \
-             project in current working directory is no longer supported, \
+             package in current working directory is no longer supported, \
              use `cargo install --path .` instead. \
              Use `cargo build` if you want to simply build the package.",
-        ).run();
+        )
+        .run();
     assert_has_not_installed_exe(cargo_home(), "foo");
 }
 
@@ -747,7 +808,8 @@ fn uninstall_cwd() {
 [INSTALLING] {home}/bin/foo[EXE]
 warning: be sure to add `{home}/bin` to your PATH to be able to run the installed binaries",
             home = cargo_home().display(),
-        )).run();
+        ))
+        .run();
     assert_has_installed_exe(cargo_home(), "foo");
 
     p.cargo("uninstall")
@@ -756,7 +818,8 @@ warning: be sure to add `{home}/bin` to your PATH to be able to run the installe
             "\
              [REMOVING] {home}/bin/foo[EXE]",
             home = cargo_home().display()
-        )).run();
+        ))
+        .run();
     assert_has_not_installed_exe(cargo_home(), "foo");
 }
 
@@ -769,7 +832,8 @@ fn uninstall_cwd_not_installed() {
         .with_stderr(
             "\
              error: package `foo v0.0.1 ([CWD])` is not installed",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -789,7 +853,8 @@ fn uninstall_cwd_no_project() {
 Caused by:
   {err_msg} (os error 2)",
             err_msg = err_msg,
-        )).run();
+        ))
+        .run();
 }
 
 #[test]
@@ -805,7 +870,8 @@ fn do_not_rebuilds_on_local_install() {
 [INSTALLING] [..]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
 
     assert!(p.build_dir().exists());
     assert!(p.release_bin("foo").exists());
@@ -841,7 +907,8 @@ fn git_with_lockfile() {
             [dependencies]
             bar = { path = "bar" }
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("bar/src/lib.rs", "fn main() {}")
         .file(
@@ -856,7 +923,8 @@ fn git_with_lockfile() {
             name = "bar"
             version = "0.1.0"
         "#,
-        ).build();
+        )
+        .build();
 
     cargo_process("install --git")
         .arg(p.url().to_string())
@@ -903,7 +971,8 @@ fn use_path_workspace() {
             [workspace]
             members = ["baz"]
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .file(
             "baz/Cargo.toml",
             r#"
@@ -915,7 +984,8 @@ fn use_path_workspace() {
             [dependencies]
             foo = "1"
         "#,
-        ).file("baz/src/lib.rs", "")
+        )
+        .file("baz/src/lib.rs", "")
         .build();
 
     p.cargo("build").run();
@@ -940,10 +1010,14 @@ fn dev_dependencies_no_check() {
             [dev-dependencies]
             baz = "1.0.0"
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .build();
 
-    p.cargo("build").with_status(101).run();
+    p.cargo("build")
+        .with_status(101)
+        .with_stderr_contains("[..] no matching package named `baz` found")
+        .run();
     p.cargo("install").run();
 }
 
@@ -962,7 +1036,8 @@ fn dev_dependencies_lock_file_untouched() {
             [dev-dependencies]
             bar = { path = "a" }
         "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .file("a/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("a/src/lib.rs", "")
         .build();
@@ -1004,7 +1079,7 @@ fn vers_precise() {
     pkg("foo", "0.1.2");
 
     cargo_process("install foo --vers 0.1.1")
-        .with_stderr_contains("[DOWNLOADING] foo v0.1.1 (registry [..])")
+        .with_stderr_contains("[DOWNLOADED] foo v0.1.1 (registry [..])")
         .run();
 }
 
@@ -1014,7 +1089,7 @@ fn version_too() {
     pkg("foo", "0.1.2");
 
     cargo_process("install foo --version 0.1.1")
-        .with_stderr_contains("[DOWNLOADING] foo v0.1.1 (registry [..])")
+        .with_stderr_contains("[DOWNLOADED] foo v0.1.1 (registry [..])")
         .run();
 }
 
@@ -1030,7 +1105,8 @@ fn not_both_vers_and_version() {
 error: The argument '--version <VERSION>' was provided more than once, \
 but cannot be used multiple times
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -1045,7 +1121,8 @@ warning: the `--vers` provided, `0.1`, is not a valid semver version
 historically Cargo treated this as a semver version requirement accidentally
 and will continue to do so, but this behavior will be removed eventually
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -1073,7 +1150,8 @@ error: package id specification `bar` matched no packages
 [SUMMARY] Successfully uninstalled foo! Failed to uninstall bar (see error(s) above).
 error: some packages failed to uninstall
 ",
-        ).run();
+        )
+        .run();
 
     assert_has_not_installed_exe(cargo_home(), "foo");
     assert_has_not_installed_exe(cargo_home(), "bar");
@@ -1110,7 +1188,8 @@ fn install_respects_lock_file() {
         .file(
             "src/main.rs",
             "extern crate foo; extern crate bar; fn main() {}",
-        ).file(
+        )
+        .file(
             "Cargo.lock",
             r#"
 [[package]]
@@ -1125,7 +1204,8 @@ dependencies = [
  "bar 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
 ]
 "#,
-        ).publish();
+        )
+        .publish();
 
     cargo_process("install foo").run();
 }
@@ -1140,7 +1220,8 @@ fn lock_file_path_deps_ok() {
         .file(
             "src/main.rs",
             "extern crate foo; extern crate bar; fn main() {}",
-        ).file(
+        )
+        .file(
             "Cargo.lock",
             r#"
 [[package]]
@@ -1154,7 +1235,8 @@ dependencies = [
  "bar 0.1.0",
 ]
 "#,
-        ).publish();
+        )
+        .publish();
 
     cargo_process("install foo").run();
 }
@@ -1167,7 +1249,8 @@ fn install_empty_argument() {
         .with_status(1)
         .with_stderr_contains(
             "[ERROR] The argument '<crate>...' requires a value but none was supplied",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -1187,19 +1270,15 @@ fn git_repo_replace() {
     path.push(".cargo/.crates.toml");
 
     assert_ne!(old_rev, new_rev);
-    assert!(
-        fs::read_to_string(path.clone())
-            .unwrap()
-            .contains(&format!("{}", old_rev))
-    );
+    assert!(fs::read_to_string(path.clone())
+        .unwrap()
+        .contains(&format!("{}", old_rev)));
     cargo_process("install --force --git")
         .arg(p.url().to_string())
         .run();
-    assert!(
-        fs::read_to_string(path)
-            .unwrap()
-            .contains(&format!("{}", new_rev))
-    );
+    assert!(fs::read_to_string(path)
+        .unwrap()
+        .contains(&format!("{}", new_rev)));
 }
 
 #[test]
@@ -1218,7 +1297,8 @@ fn workspace_uses_workspace_target_dir() {
                 [dependencies]
                 bar = { path = 'bar' }
             "#,
-        ).file("src/main.rs", "fn main() {}")
+        )
+        .file("src/main.rs", "fn main() {}")
         .file("bar/Cargo.toml", &basic_manifest("bar", "0.1.0"))
         .file("bar/src/main.rs", "fn main() {}")
         .build();
@@ -1232,20 +1312,21 @@ fn workspace_uses_workspace_target_dir() {
 [INSTALLING] [..]
 warning: be sure to add `[..]` to your PATH to be able to run the installed binaries
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
-fn install_ignores_cargo_config() {
+fn install_ignores_local_cargo_config() {
     pkg("bar", "0.0.1");
 
     let p = project()
         .file(
             ".cargo/config",
             r#"
-            [build]
-            target = "non-existing-target"
-        "#,
+                [build]
+                target = "non-existing-target"
+            "#,
         )
         .file("src/main.rs", "fn main() {}")
         .build();
@@ -1253,3 +1334,24 @@ fn install_ignores_cargo_config() {
     p.cargo("install bar").run();
     assert_has_installed_exe(cargo_home(), "bar");
 }
+
+#[test]
+fn install_global_cargo_config() {
+    pkg("bar", "0.0.1");
+
+    let config = cargo_home().join("config");
+    let mut toml = fs::read_to_string(&config).unwrap_or(String::new());
+
+    toml.push_str(
+        r#"
+        [build]
+        target = 'nonexistent'
+    "#,
+    );
+    fs::write(&config, toml).unwrap();
+
+    cargo_process("install bar")
+        .with_status(101)
+        .with_stderr_contains("[..]--target nonexistent[..]")
+        .run();
+}
