@@ -4,9 +4,9 @@ use cargo::core::dependency::Kind;
 use cargo::core::{enable_nightly_features, Dependency};
 use cargo::util::Config;
 
-use support::project;
-use support::registry::Package;
-use support::resolver::{
+use crate::support::project;
+use crate::support::registry::Package;
+use crate::support::resolver::{
     assert_contains, assert_same, dep, dep_kind, dep_loc, dep_req, loc_names, names, pkg, pkg_dep,
     pkg_id, pkg_loc, registry, registry_strategy, resolve, resolve_and_validated,
     resolve_with_config, PrettyPrintRegistry, ToDep, ToPkgId,
@@ -14,6 +14,7 @@ use support::resolver::{
 
 use proptest::collection::vec;
 use proptest::prelude::*;
+use proptest::*;
 
 /// NOTE: proptest is a form of fuzz testing. It generates random input and makes shore that
 /// certain universal truths are upheld. Therefore, it can pass when there is a problem,
@@ -1088,23 +1089,23 @@ fn incomplete_information_skiping_3() {
     // minimized bug found in:
     // https://github.com/rust-lang/cargo/commit/003c29b0c71e5ea28fbe8e72c148c755c9f3f8d9
     let input = vec![
-        pkg!{("to_yank", "3.0.3")},
-        pkg!{("to_yank", "3.3.0")},
-        pkg!{("to_yank", "3.3.1")},
-        pkg!{("a", "3.3.0") => [
+        pkg! {("to_yank", "3.0.3")},
+        pkg! {("to_yank", "3.3.0")},
+        pkg! {("to_yank", "3.3.1")},
+        pkg! {("a", "3.3.0") => [
             dep_req("to_yank", "=3.0.3"),
         ] },
-        pkg!{("a", "3.3.2") => [
+        pkg! {("a", "3.3.2") => [
             dep_req("to_yank", "<=3.3.0"),
         ] },
-        pkg!{("b", "0.1.3") => [
+        pkg! {("b", "0.1.3") => [
             dep_req("a", "=3.3.0"),
         ] },
-        pkg!{("b", "2.0.2") => [
+        pkg! {("b", "2.0.2") => [
             dep_req("to_yank", "3.3.0"),
             dep("a"),
         ] },
-        pkg!{("b", "2.3.3") => [
+        pkg! {("b", "2.3.3") => [
             dep_req("to_yank", "3.3.0"),
             dep_req("a", "=3.3.0"),
         ] },
