@@ -1,6 +1,6 @@
+use crate::support;
+use crate::support::{basic_bin_manifest, basic_lib_manifest, project, Project};
 use cargo::util::paths::dylib_path_envvar;
-use support;
-use support::{basic_bin_manifest, basic_lib_manifest, project, Project};
 
 #[test]
 fn simple() {
@@ -14,7 +14,8 @@ fn simple() {
 [COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/foo[EXE]`",
-        ).with_stdout("hello")
+        )
+        .with_stdout("hello")
         .run();
     assert!(p.bin("foo").is_file());
 }
@@ -51,7 +52,8 @@ fn quiet_and_verbose_config() {
             [term]
             verbose = true
         "#,
-        ).file("src/main.rs", r#"fn main() { println!("hello"); }"#)
+        )
+        .file("src/main.rs", r#"fn main() { println!("hello"); }"#)
         .build();
 
     p.cargo("run -q").run();
@@ -68,7 +70,8 @@ fn simple_with_args() {
                 assert_eq!(std::env::args().nth(2).unwrap(), "world");
             }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("run hello world").run();
 }
@@ -126,7 +129,8 @@ fn no_main_file() {
         .with_stderr(
             "[ERROR] a bin target must be available \
              for `cargo run`\n",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -144,7 +148,8 @@ fn too_many_bins() {
             "[ERROR] `cargo run` requires that a package only \
              have one executable; use the `--bin` option \
              to specify which one to run\navailable binaries: [..]\n",
-        ).run();
+        )
+        .run();
 
     // Using [..] here because the order is not stable
     p.cargo("run")
@@ -155,7 +160,8 @@ fn too_many_bins() {
              Use the `--bin` option to specify a binary, or (on \
              nightly) the `default-run` manifest key.\
              \navailable binaries: [..]\n",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -169,14 +175,16 @@ fn specify_name() {
             extern crate foo;
             fn main() { println!("hello a.rs"); }
         "#,
-        ).file(
+        )
+        .file(
             "src/bin/b.rs",
             r#"
             #[allow(unused_extern_crates)]
             extern crate foo;
             fn main() { println!("hello b.rs"); }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("run --bin a -v")
         .with_stderr(
@@ -186,7 +194,8 @@ fn specify_name() {
 [RUNNING] `rustc [..] src/bin/a.rs [..]`
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/a[EXE]`",
-        ).with_stdout("hello a.rs")
+        )
+        .with_stdout("hello a.rs")
         .run();
 
     p.cargo("run --bin b -v")
@@ -196,7 +205,8 @@ fn specify_name() {
 [RUNNING] `rustc [..] src/bin/b.rs [..]`
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/b[EXE]`",
-        ).with_stdout("hello b.rs")
+        )
+        .with_stdout("hello b.rs")
         .run();
 }
 
@@ -214,7 +224,8 @@ fn specify_default_run() {
             authors = []
             default-run = "a"
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file("src/bin/a.rs", r#"fn main() { println!("hello A"); }"#)
         .file("src/bin/b.rs", r#"fn main() { println!("hello B"); }"#)
         .build();
@@ -247,7 +258,8 @@ fn bogus_default_run() {
             authors = []
             default-run = "b"
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file("src/bin/a.rs", r#"fn main() { println!("hello A"); }"#)
         .build();
 
@@ -270,7 +282,8 @@ fn default_run_unstable() {
             authors = []
             default-run = "a"
         "#,
-        ).file("src/bin/a.rs", r#"fn main() { println!("hello A"); }"#)
+        )
+        .file("src/bin/a.rs", r#"fn main() { println!("hello A"); }"#)
         .build();
 
     p.cargo("run")
@@ -288,7 +301,8 @@ this Cargo does not support nightly features, but if you
 switch to nightly channel you can add
 `cargo-features = ["default-run"]` to enable this feature
 "#,
-        ).run();
+        )
+        .run();
 
     p.cargo("run")
         .masquerade_as_nightly_cargo()
@@ -304,7 +318,8 @@ Caused by:
 
 consider adding `cargo-features = ["default-run"]` to the manifest
 "#,
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -321,7 +336,8 @@ fn run_example() {
 [COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/examples/a[EXE]`",
-        ).with_stdout("example")
+        )
+        .with_stdout("example")
         .run();
 }
 
@@ -339,7 +355,8 @@ fn run_library_example() {
             name = "bar"
             crate_type = ["lib"]
         "#,
-        ).file("src/lib.rs", "")
+        )
+        .file("src/lib.rs", "")
         .file("examples/bar.rs", "fn foo() {}")
         .build();
 
@@ -405,13 +422,15 @@ fn autodiscover_examples_project(rust_edition: &str, autoexamples: Option<bool>)
                 rust_edition = rust_edition,
                 autoexamples = autoexamples
             ),
-        ).file("examples/a.rs", r#"fn main() { println!("example"); }"#)
+        )
+        .file("examples/a.rs", r#"fn main() { println!("example"); }"#)
         .file(
             "examples/do_magic.rs",
             r#"
                 fn main() { println!("magic example"); }
             "#,
-        ).build()
+        )
+        .build()
 }
 
 #[test]
@@ -442,7 +461,8 @@ For more information on this warning you can consult
 https://github.com/rust-lang/cargo/issues/5330
 error: no example target named `a`
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -458,7 +478,8 @@ fn run_example_autodiscover_2015_with_autoexamples_enabled() {
 [COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/examples/a[EXE]`",
-        ).with_stdout("example")
+        )
+        .with_stdout("example")
         .run();
 }
 
@@ -488,7 +509,8 @@ fn run_example_autodiscover_2018() {
 [COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/examples/a[EXE]`",
-        ).with_stdout("example")
+        )
+        .with_stdout("example")
         .run();
 }
 
@@ -502,7 +524,7 @@ fn autobins_disables() {
             name = "foo"
             version = "0.0.1"
             autobins = false
-            "#
+            "#,
         )
         .file("src/lib.rs", "pub mod bin;")
         .file("src/bin/mod.rs", "// empty")
@@ -526,7 +548,8 @@ fn run_bins() {
         .with_status(1)
         .with_stderr_contains(
             "error: Found argument '--bins' which wasn't expected, or isn't valid in this context",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -539,7 +562,8 @@ fn run_with_filename() {
             extern crate foo;
             fn main() { println!("hello a.rs"); }
         "#,
-        ).file("examples/a.rs", r#"fn main() { println!("example"); }"#)
+        )
+        .file("examples/a.rs", r#"fn main() { println!("example"); }"#)
         .build();
 
     p.cargo("run --bin bin.rs")
@@ -554,7 +578,8 @@ fn run_with_filename() {
 [ERROR] no bin target named `a.rs`
 
 Did you mean `a`?",
-        ).run();
+        )
+        .run();
 
     p.cargo("run --example example.rs")
         .with_status(101)
@@ -568,7 +593,8 @@ Did you mean `a`?",
 [ERROR] no example target named `a.rs`
 
 Did you mean `a`?",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -584,7 +610,8 @@ fn either_name_or_example() {
             "[ERROR] `cargo run` can run at most one \
              executable, but multiple were \
              specified",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -594,7 +621,8 @@ fn one_bin_multiple_examples() {
         .file(
             "src/bin/main.rs",
             r#"fn main() { println!("hello main.rs"); }"#,
-        ).file("examples/a.rs", r#"fn main() { println!("hello a.rs"); }"#)
+        )
+        .file("examples/a.rs", r#"fn main() { println!("hello a.rs"); }"#)
         .file("examples/b.rs", r#"fn main() { println!("hello b.rs"); }"#)
         .build();
 
@@ -604,7 +632,8 @@ fn one_bin_multiple_examples() {
 [COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/main[EXE]`",
-        ).with_stdout("hello main.rs")
+        )
+        .with_stdout("hello main.rs")
         .run();
 }
 
@@ -623,7 +652,8 @@ fn example_with_release_flag() {
             version = "*"
             path = "bar"
         "#,
-        ).file(
+        )
+        .file(
             "examples/a.rs",
             r#"
             extern crate bar;
@@ -637,7 +667,8 @@ fn example_with_release_flag() {
                 bar::baz();
             }
         "#,
-        ).file("bar/Cargo.toml", &basic_lib_manifest("bar"))
+        )
+        .file("bar/Cargo.toml", &basic_lib_manifest("bar"))
         .file(
             "bar/src/bar.rs",
             r#"
@@ -649,7 +680,8 @@ fn example_with_release_flag() {
                 }
             }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("run -v --release --example a")
         .with_stderr(
@@ -672,11 +704,13 @@ fn example_with_release_flag() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] `target/release/examples/a[EXE]`
 ",
-        ).with_stdout(
+        )
+        .with_stdout(
             "\
 fast1
 fast2",
-        ).run();
+        )
+        .run();
 
     p.cargo("run -v --example a")
         .with_stderr(
@@ -699,11 +733,13 @@ fast2",
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 [RUNNING] `target/debug/examples/a[EXE]`
 ",
-        ).with_stdout(
+        )
+        .with_stdout(
             "\
 slow1
 slow2",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -720,10 +756,12 @@ fn run_dylib_dep() {
             [dependencies.bar]
             path = "bar"
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             r#"extern crate bar; fn main() { bar::bar(); }"#,
-        ).file(
+        )
+        .file(
             "bar/Cargo.toml",
             r#"
             [package]
@@ -735,7 +773,8 @@ fn run_dylib_dep() {
             name = "bar"
             crate-type = ["dylib"]
         "#,
-        ).file("bar/src/lib.rs", "pub fn bar() {}")
+        )
+        .file("bar/src/lib.rs", "pub fn bar() {}")
         .build();
 
     p.cargo("run hello world").run();
@@ -749,7 +788,8 @@ fn release_works() {
             r#"
             fn main() { if cfg!(debug_assertions) { panic!() } }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("run --release")
         .with_stderr(
@@ -758,7 +798,8 @@ fn release_works() {
 [FINISHED] release [optimized] target(s) in [..]
 [RUNNING] `target/release/foo[EXE]`
 ",
-        ).run();
+        )
+        .run();
     assert!(p.release_bin("foo").is_file());
 }
 
@@ -776,7 +817,8 @@ fn run_bin_different_name() {
             [[bin]]
             name = "bar"
         "#,
-        ).file("src/bar.rs", "fn main() {}")
+        )
+        .file("src/bar.rs", "fn main() {}")
         .build();
 
     p.cargo("run").run();
@@ -796,7 +838,8 @@ fn dashes_are_forwarded() {
                 assert_eq!(s[4], "b");
             }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("run -- -- a -- b").run();
 }
@@ -816,7 +859,8 @@ fn run_from_executable_folder() {
             "\
              [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]\n\
              [RUNNING] `./foo[EXE]`",
-        ).with_stdout("hello")
+        )
+        .with_stdout("hello")
         .run();
 }
 
@@ -842,7 +886,8 @@ fn run_with_library_paths() {
             authors = []
             build = "build.rs"
         "#,
-        ).file(
+        )
+        .file(
             "build.rs",
             &format!(
                 r##"
@@ -854,7 +899,8 @@ fn run_with_library_paths() {
                 dir1.display(),
                 dir2.display()
             ),
-        ).file(
+        )
+        .file(
             "src/main.rs",
             &format!(
                 r##"
@@ -869,7 +915,8 @@ fn run_with_library_paths() {
                 dir1.display(),
                 dir2.display()
             ),
-        ).build();
+        )
+        .build();
 
     p.cargo("run").run();
 }
@@ -897,7 +944,8 @@ fn library_paths_sorted_alphabetically() {
             authors = []
             build = "build.rs"
         "#,
-        ).file(
+        )
+        .file(
             "build.rs",
             &format!(
                 r##"
@@ -911,7 +959,8 @@ fn library_paths_sorted_alphabetically() {
                 dir2.display(),
                 dir3.display()
             ),
-        ).file(
+        )
+        .file(
             "src/main.rs",
             &format!(
                 r##"
@@ -926,7 +975,8 @@ fn library_paths_sorted_alphabetically() {
         "##,
                 dylib_path_envvar()
             ),
-        ).build();
+        )
+        .build();
 
     p.cargo("run").run();
 }
@@ -966,7 +1016,8 @@ fn run_multiple_packages() {
             [[bin]]
             name = "foo"
         "#,
-        ).file("foo/src/foo.rs", "fn main() { println!(\"foo\"); }")
+        )
+        .file("foo/src/foo.rs", "fn main() { println!(\"foo\"); }")
         .file("foo/d1/Cargo.toml", &basic_bin_manifest("d1"))
         .file("foo/d1/src/lib.rs", "")
         .file("foo/d1/src/main.rs", "fn main() { println!(\"d1\"); }")
@@ -1017,7 +1068,8 @@ fn explicit_bin_with_args() {
                 assert_eq!(std::env::args().nth(2).unwrap(), "world");
             }
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("run --bin foo hello world").run();
 }
@@ -1031,7 +1083,8 @@ fn run_workspace() {
             [workspace]
             members = ["a", "b"]
         "#,
-        ).file("a/Cargo.toml", &basic_bin_manifest("a"))
+        )
+        .file("a/Cargo.toml", &basic_bin_manifest("a"))
         .file("a/src/main.rs", r#"fn main() {println!("run-a");}"#)
         .file("b/Cargo.toml", &basic_bin_manifest("b"))
         .file("b/src/main.rs", r#"fn main() {println!("run-b");}"#)
@@ -1043,7 +1096,8 @@ fn run_workspace() {
             "\
 [ERROR] `cargo run` requires that a package only have one executable[..]
 available binaries: a, b",
-        ).run();
+        )
+        .run();
     p.cargo("run --bin a")
         .with_status(0)
         .with_stdout("run-a")
@@ -1059,7 +1113,8 @@ fn default_run_workspace() {
             [workspace]
             members = ["a", "b"]
         "#,
-        ).file(
+        )
+        .file(
             "a/Cargo.toml",
             r#"
             cargo-features = ["default-run"]
@@ -1069,7 +1124,8 @@ fn default_run_workspace() {
             version = "0.0.1"
             default-run = "a"
         "#,
-        ).file("a/src/main.rs", r#"fn main() {println!("run-a");}"#)
+        )
+        .file("a/src/main.rs", r#"fn main() {println!("run-a");}"#)
         .file("b/Cargo.toml", &basic_bin_manifest("b"))
         .file("b/src/main.rs", r#"fn main() {println!("run-b");}"#)
         .build();
@@ -1080,3 +1136,88 @@ fn default_run_workspace() {
         .with_stdout("run-a")
         .run();
 }
+
+#[test]
+#[cfg(target_os = "macos")]
+fn run_link_system_path_macos() {
+    use crate::support::paths::{self, CargoPathExt};
+    use std::fs;
+    // Check that the default system library path is honored.
+    // First, build a shared library that will be accessed from
+    // DYLD_FALLBACK_LIBRARY_PATH.
+    let p = project()
+        .file(
+            "Cargo.toml",
+            r#"
+            [project]
+            name = "foo"
+            version = "0.0.1"
+            [lib]
+            crate-type = ["cdylib"]
+            "#,
+        )
+        .file(
+            "src/lib.rs",
+            "#[no_mangle] pub extern fn something_shared() {}",
+        )
+        .build();
+    p.cargo("build").run();
+
+    // This is convoluted. Since this test can't modify things in /usr,
+    // this needs to dance around to check that things work.
+    //
+    // The default DYLD_FALLBACK_LIBRARY_PATH is:
+    //      $(HOME)/lib:/usr/local/lib:/lib:/usr/lib
+    //
+    // This will make use of ~/lib in the path, but the default cc link
+    // path is /usr/lib:/usr/local/lib. So first need to build in one
+    // location, and then move it to ~/lib.
+    //
+    // 1. Build with rustc-link-search pointing to libfoo so the initial
+    //    binary can be linked.
+    // 2. Move the library to ~/lib
+    // 3. Run `cargo run` to make sure it can still find the library in
+    //    ~/lib.
+    //
+    // This should be equivalent to having the library in /usr/local/lib.
+    let p2 = project()
+        .at("bar")
+        .file("Cargo.toml", &basic_bin_manifest("bar"))
+        .file(
+            "src/main.rs",
+            r#"
+            extern {
+                fn something_shared();
+            }
+            fn main() {
+                unsafe { something_shared(); }
+            }
+            "#,
+        )
+        .file(
+            "build.rs",
+            &format!(
+                r#"
+            fn main() {{
+                println!("cargo:rustc-link-lib=foo");
+                println!("cargo:rustc-link-search={}");
+            }}
+            "#,
+                p.target_debug_dir().display()
+            ),
+        )
+        .build();
+    p2.cargo("build").run();
+    p2.cargo("test").run();
+
+    let libdir = paths::home().join("lib");
+    fs::create_dir(&libdir).unwrap();
+    fs::rename(
+        p.target_debug_dir().join("libfoo.dylib"),
+        libdir.join("libfoo.dylib"),
+    )
+    .unwrap();
+    p.root().rm_rf();
+    p2.cargo("run").run();
+    p2.cargo("test").run();
+}
