@@ -382,7 +382,7 @@ impl Project {
     ///             .with_stdout("bar\n")
     ///             .run();
     pub fn process<T: AsRef<OsStr>>(&self, program: T) -> Execs {
-        let mut p = ::support::process(program);
+        let mut p = crate::support::process(program);
         p.cwd(self.root());
         execs().with_process_builder(p)
     }
@@ -516,7 +516,8 @@ pub fn cargo_dir() -> PathBuf {
                 }
                 path
             })
-        }).unwrap_or_else(|| panic!("CARGO_BIN_PATH wasn't set. Cannot continue running test"))
+        })
+        .unwrap_or_else(|| panic!("CARGO_BIN_PATH wasn't set. Cannot continue running test"))
 }
 
 pub fn cargo_exe() -> PathBuf {
@@ -549,6 +550,7 @@ pub struct Execs {
     expect_stderr_unordered: Vec<String>,
     expect_neither_contains: Vec<String>,
     expect_json: Option<Vec<Value>>,
+    expect_json_contains_unordered: Vec<Value>,
     stream_output: bool,
 }
 
@@ -688,6 +690,24 @@ impl Execs {
         self
     }
 
+    /// Verify JSON output contains the given objects (in any order) somewhere
+    /// in its output.
+    ///
+    /// CAUTION: Be very careful when using this. Make sure every object is
+    /// unique (not a subset of one another). Also avoid using objects that
+    /// could possibly match multiple output lines unless you're very sure of
+    /// what you are doing.
+    ///
+    /// See `with_json` for more detail.
+    pub fn with_json_contains_unordered(&mut self, expected: &str) -> &mut Self {
+        self.expect_json_contains_unordered.extend(
+            expected
+                .split("\n\n")
+                .map(|line| line.parse().expect("line to be a valid JSON value")),
+        );
+        self
+    }
+
     /// Forward subordinate process stdout/stderr to the terminal.
     /// Useful for printf debugging of the tests.
     /// CAUTION: CI will fail if you leave this in your test!
@@ -761,6 +781,32 @@ impl Execs {
         }
     }
 
+    fn verify_checks_output(&self, output: &Output) {
+        if self.expect_exit_code.unwrap_or(0) != 0
+            && self.expect_stdout.is_none()
+            && self.expect_stdin.is_none()
+            && self.expect_stderr.is_none()
+            && self.expect_stdout_contains.is_empty()
+            && self.expect_stderr_contains.is_empty()
+            && self.expect_either_contains.is_empty()
+            && self.expect_stdout_contains_n.is_empty()
+            && self.expect_stdout_not_contains.is_empty()
+            && self.expect_stderr_not_contains.is_empty()
+            && self.expect_stderr_unordered.is_empty()
+            && self.expect_neither_contains.is_empty()
+            && self.expect_json.is_none()
+            && self.expect_json_contains_unordered.is_empty()
+        {
+            panic!(
+                "`with_status()` is used, but no output is checked.\n\
+                 The test must check the output to ensure the correct error is triggered.\n\
+                 --- stdout\n{}\n--- stderr\n{}",
+                String::from_utf8_lossy(&output.stdout),
+                String::from_utf8_lossy(&output.stderr),
+            );
+        }
+    }
+
     fn match_process(&self, process: &ProcessBuilder) -> MatchResult {
         println!("running {}", process);
         let res = if self.stream_output {
@@ -797,6 +843,7 @@ impl Execs {
     }
 
     fn match_output(&self, actual: &Output) -> MatchResult {
+        self.verify_checks_output(actual);
         self.match_status(actual)
             .and(self.match_stdout(actual))
             .and(self.match_stderr(actual))
@@ -940,6 +987,33 @@ impl Execs {
                 self.match_json(obj, line)?;
             }
         }
+
+        if !self.expect_json_contains_unordered.is_empty() {
+            let stdout = str::from_utf8(&actual.stdout)
+                .map_err(|_| "stdout was not utf8 encoded".to_owned())?;
+            let mut lines = stdout
+                .lines()
+                .filter(|line| line.starts_with('{'))
+                .collect::<Vec<_>>();
+            for obj in &self.expect_json_contains_unordered {
+                match lines
+                    .iter()
+                    .position(|line| self.match_json(obj, line).is_ok())
+                {
+                    Some(index) => lines.remove(index),
+                    None => {
+                        return Err(format!(
+                            "Did not find expected JSON:\n\
+                             {}\n\
+                             Remaining available output:\n\
+                             {}\n",
+                            serde_json::to_string_pretty(obj).unwrap(),
+                            lines.join("\n")
+                        ));
+                    }
+                };
+            }
+        }
         Ok(())
     }
 
@@ -968,20 +1042,17 @@ impl Execs {
                     None => out.to_string(),
                     Some(ref p) => match p.get_cwd() {
                         None => out.to_string(),
-                        Some(cwd) => out
-                            .replace( "[CWD]", &cwd.display().to_string())
-                        ,
+                        Some(cwd) => out.replace("[CWD]", &cwd.display().to_string()),
                     },
                 };
 
                 // On Windows, we need to use a wildcard for the drive,
                 // because we don't actually know what it will be.
-                let replaced = replaced
-                    .replace("[ROOT]",
-                             if cfg!(windows) { r#"[..]:\"# } else { "/" });
+                let replaced =
+                    replaced.replace("[ROOT]", if cfg!(windows) { r#"[..]:\"# } else { "/" });
 
                 replaced
-            },
+            }
             None => return Ok(()),
         };
 
@@ -1098,7 +1169,7 @@ impl Execs {
                                  {}\n",
                                 e_line,
                                 a.join("\n")
-                            ))
+                            ));
                         }
                     };
                 }
@@ -1121,16 +1192,7 @@ impl Execs {
             Ok(actual) => actual,
         };
 
-        match find_mismatch(expected, &actual) {
-            Some((expected_part, actual_part)) => Err(format!(
-                "JSON mismatch\nExpected:\n{}\nWas:\n{}\nExpected part:\n{}\nActual part:\n{}\n",
-                serde_json::to_string_pretty(expected).unwrap(),
-                serde_json::to_string_pretty(&actual).unwrap(),
-                serde_json::to_string_pretty(expected_part).unwrap(),
-                serde_json::to_string_pretty(actual_part).unwrap(),
-            )),
-            None => Ok(()),
-        }
+        find_json_mismatch(expected, &actual)
     }
 
     fn diff_lines<'a>(
@@ -1157,13 +1219,14 @@ impl Execs {
                 (Some(a), None) => Some(format!("{:3} -\n    + |{}|\n", i, a)),
                 (None, Some(e)) => Some(format!("{:3} - |{}|\n    +\n", i, e)),
                 (None, None) => panic!("Cannot get here"),
-            }).collect()
+            })
+            .collect()
     }
 }
 
 impl Drop for Execs {
     fn drop(&mut self) {
-        if !self.ran {
+        if !self.ran && !std::thread::panicking() {
             panic!("forgot to run this command");
         }
     }
@@ -1220,12 +1283,28 @@ fn lines_match_works() {
     assert!(!lines_match("b", "cb"));
 }
 
-// Compares JSON object for approximate equality.
-// You can use `[..]` wildcard in strings (useful for OS dependent things such
-// as paths).  You can use a `"{...}"` string literal as a wildcard for
-// arbitrary nested JSON (useful for parts of object emitted by other programs
-// (e.g. rustc) rather than Cargo itself).  Arrays are sorted before comparison.
-fn find_mismatch<'a>(expected: &'a Value, actual: &'a Value) -> Option<(&'a Value, &'a Value)> {
+/// Compares JSON object for approximate equality.
+/// You can use `[..]` wildcard in strings (useful for OS dependent things such
+/// as paths).  You can use a `"{...}"` string literal as a wildcard for
+/// arbitrary nested JSON (useful for parts of object emitted by other programs
+/// (e.g. rustc) rather than Cargo itself).  Arrays are sorted before comparison.
+pub fn find_json_mismatch(expected: &Value, actual: &Value) -> Result<(), String> {
+    match find_json_mismatch_r(expected, &actual) {
+        Some((expected_part, actual_part)) => Err(format!(
+            "JSON mismatch\nExpected:\n{}\nWas:\n{}\nExpected part:\n{}\nActual part:\n{}\n",
+            serde_json::to_string_pretty(expected).unwrap(),
+            serde_json::to_string_pretty(&actual).unwrap(),
+            serde_json::to_string_pretty(expected_part).unwrap(),
+            serde_json::to_string_pretty(actual_part).unwrap(),
+        )),
+        None => Ok(()),
+    }
+}
+
+fn find_json_mismatch_r<'a>(
+    expected: &'a Value,
+    actual: &'a Value,
+) -> Option<(&'a Value, &'a Value)> {
     use serde_json::Value::*;
     match (expected, actual) {
         (&Number(ref l), &Number(ref r)) if l == r => None,
@@ -1240,7 +1319,7 @@ fn find_mismatch<'a>(expected: &'a Value, actual: &'a Value) -> Option<(&'a Valu
             let mut r = r.iter().collect::<Vec<_>>();
 
             l.retain(
-                |l| match r.iter().position(|r| find_mismatch(l, r).is_none()) {
+                |l| match r.iter().position(|r| find_json_mismatch_r(l, r).is_none()) {
                     Some(i) => {
                         r.remove(i);
                         false
@@ -1265,7 +1344,7 @@ fn find_mismatch<'a>(expected: &'a Value, actual: &'a Value) -> Option<(&'a Valu
 
             l.values()
                 .zip(r.values())
-                .filter_map(|(l, r)| find_mismatch(l, r))
+                .filter_map(|(l, r)| find_json_mismatch_r(l, r))
                 .nth(0)
         }
         (&Null, &Null) => None,
@@ -1301,7 +1380,7 @@ fn zip_all<T, I1: Iterator<Item = T>, I2: Iterator<Item = T>>(a: I1, b: I2) -> Z
 }
 
 impl fmt::Debug for Execs {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "execs")
     }
 }
@@ -1323,6 +1402,7 @@ pub fn execs() -> Execs {
         expect_stderr_unordered: Vec::new(),
         expect_neither_contains: Vec::new(),
         expect_json: None,
+        expect_json_contains_unordered: Vec::new(),
         stream_output: false,
     }
 }
@@ -1450,43 +1530,39 @@ pub fn process<T: AsRef<OsStr>>(t: T) -> cargo::util::ProcessBuilder {
 fn _process(t: &OsStr) -> cargo::util::ProcessBuilder {
     let mut p = cargo::util::process(t);
     p.cwd(&paths::root())
-     .env_remove("CARGO_HOME")
-     .env("HOME", paths::home())
-     .env("CARGO_HOME", paths::home().join(".cargo"))
-     .env("__CARGO_TEST_ROOT", paths::root())
-
-     // Force cargo to think it's on the stable channel for all tests, this
-     // should hopefully not surprise us as we add cargo features over time and
-     // cargo rides the trains.
-     .env("__CARGO_TEST_CHANNEL_OVERRIDE_DO_NOT_USE_THIS", "stable")
-
-     // For now disable incremental by default as support hasn't ridden to the
-     // stable channel yet. Once incremental support hits the stable compiler we
-     // can switch this to one and then fix the tests.
-     .env("CARGO_INCREMENTAL", "0")
-
-     // This env var can switch the git backend from libgit2 to git2-curl, which
-     // can tweak error messages and cause some tests to fail, so let's forcibly
-     // remove it.
-     .env_remove("CARGO_HTTP_CHECK_REVOKE")
-
-     .env_remove("__CARGO_DEFAULT_LIB_METADATA")
-     .env_remove("RUSTC")
-     .env_remove("RUSTDOC")
-     .env_remove("RUSTC_WRAPPER")
-     .env_remove("RUSTFLAGS")
-     .env_remove("XDG_CONFIG_HOME")      // see #2345
-     .env("GIT_CONFIG_NOSYSTEM", "1")    // keep trying to sandbox ourselves
-     .env_remove("EMAIL")
-     .env_remove("MFLAGS")
-     .env_remove("MAKEFLAGS")
-     .env_remove("CARGO_MAKEFLAGS")
-     .env_remove("GIT_AUTHOR_NAME")
-     .env_remove("GIT_AUTHOR_EMAIL")
-     .env_remove("GIT_COMMITTER_NAME")
-     .env_remove("GIT_COMMITTER_EMAIL")
-     .env_remove("CARGO_TARGET_DIR")     // we assume 'target'
-     .env_remove("MSYSTEM"); // assume cmd.exe everywhere on windows
+        .env_remove("CARGO_HOME")
+        .env("HOME", paths::home())
+        .env("CARGO_HOME", paths::home().join(".cargo"))
+        .env("__CARGO_TEST_ROOT", paths::root())
+        // Force cargo to think it's on the stable channel for all tests, this
+        // should hopefully not surprise us as we add cargo features over time and
+        // cargo rides the trains.
+        .env("__CARGO_TEST_CHANNEL_OVERRIDE_DO_NOT_USE_THIS", "stable")
+        // For now disable incremental by default as support hasn't ridden to the
+        // stable channel yet. Once incremental support hits the stable compiler we
+        // can switch this to one and then fix the tests.
+        .env("CARGO_INCREMENTAL", "0")
+        // This env var can switch the git backend from libgit2 to git2-curl, which
+        // can tweak error messages and cause some tests to fail, so let's forcibly
+        // remove it.
+        .env_remove("CARGO_HTTP_CHECK_REVOKE")
+        .env_remove("__CARGO_DEFAULT_LIB_METADATA")
+        .env_remove("RUSTC")
+        .env_remove("RUSTDOC")
+        .env_remove("RUSTC_WRAPPER")
+        .env_remove("RUSTFLAGS")
+        .env_remove("XDG_CONFIG_HOME") // see #2345
+        .env("GIT_CONFIG_NOSYSTEM", "1") // keep trying to sandbox ourselves
+        .env_remove("EMAIL")
+        .env_remove("MFLAGS")
+        .env_remove("MAKEFLAGS")
+        .env_remove("CARGO_MAKEFLAGS")
+        .env_remove("GIT_AUTHOR_NAME")
+        .env_remove("GIT_AUTHOR_EMAIL")
+        .env_remove("GIT_COMMITTER_NAME")
+        .env_remove("GIT_COMMITTER_EMAIL")
+        .env_remove("CARGO_TARGET_DIR") // we assume 'target'
+        .env_remove("MSYSTEM"); // assume cmd.exe everywhere on windows
     p
 }
 
